/********************************************************************************
** Form generated from reading UI file 'resourcetemplatewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RESOURCETEMPLATEWIDGET_H
#define UI_RESOURCETEMPLATEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QListView>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ResourceTemplateWidget
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *m_useTemplateCheckbox;
    QSpacerItem *m_spacer;
    QListView *m_templatesView;

    void setupUi(QWidget *ResourceTemplateWidget)
    {
        if (ResourceTemplateWidget->objectName().isEmpty())
            ResourceTemplateWidget->setObjectName("ResourceTemplateWidget");
        ResourceTemplateWidget->resize(400, 300);
        verticalLayout = new QVBoxLayout(ResourceTemplateWidget);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName("verticalLayout");
        m_useTemplateCheckbox = new QCheckBox(ResourceTemplateWidget);
        m_useTemplateCheckbox->setObjectName("m_useTemplateCheckbox");
        m_useTemplateCheckbox->setChecked(true);

        verticalLayout->addWidget(m_useTemplateCheckbox);

        m_spacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(m_spacer);

        m_templatesView = new QListView(ResourceTemplateWidget);
        m_templatesView->setObjectName("m_templatesView");

        verticalLayout->addWidget(m_templatesView);


        retranslateUi(ResourceTemplateWidget);
        QObject::connect(m_useTemplateCheckbox, &QCheckBox::clicked, m_templatesView, &QListView::setEnabled);

        QMetaObject::connectSlotsByName(ResourceTemplateWidget);
    } // setupUi

    void retranslateUi(QWidget *ResourceTemplateWidget)
    {
        (void)ResourceTemplateWidget;
    } // retranslateUi

};

namespace Ui {
    class ResourceTemplateWidget: public Ui_ResourceTemplateWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // RESOURCETEMPLATEWIDGET_H

