/****************************************************************************
** Meta object code from reading C++ file 'keyboardlayouteditor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktouch-26.08.0/src/editor/keyboardlayouteditor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keyboardlayouteditor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20KeyboardLayoutEditorE_t {};
} // unnamed namespace

template <> constexpr inline auto KeyboardLayoutEditor::qt_create_metaobjectdata<qt_meta_tag_ZN20KeyboardLayoutEditorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KeyboardLayoutEditor",
        "keyboardLayoutChanged",
        "",
        "readOnlyChanged",
        "selectedKeyChanged",
        "zoomLevelChanged",
        "setZoomLevel",
        "zoomLevel",
        "clearSelection",
        "validateSelection",
        "createNewKey",
        "createNewSpecialKey",
        "deleteSelectedKey",
        "setKeyGeometry",
        "keyIndex",
        "top",
        "left",
        "width",
        "height",
        "keyboardLayout",
        "KeyboardLayout*",
        "readOnly",
        "selectedKey",
        "AbstractKey*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'keyboardLayoutChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'readOnlyChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectedKeyChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'zoomLevelChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setZoomLevel'
        QtMocHelpers::SlotData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'clearSelection'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'validateSelection'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'createNewKey'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'createNewSpecialKey'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteSelectedKey'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'setKeyGeometry'
        QtMocHelpers::MethodData<void(int, int, int, int, int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 }, { QMetaType::Int, 15 }, { QMetaType::Int, 16 }, { QMetaType::Int, 17 },
            { QMetaType::Int, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'keyboardLayout'
        QtMocHelpers::PropertyData<KeyboardLayout*>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'readOnly'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'selectedKey'
        QtMocHelpers::PropertyData<AbstractKey*>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'zoomLevel'
        QtMocHelpers::PropertyData<int>(7, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KeyboardLayoutEditor, qt_meta_tag_ZN20KeyboardLayoutEditorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KeyboardLayoutEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractEditor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20KeyboardLayoutEditorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20KeyboardLayoutEditorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20KeyboardLayoutEditorE_t>.metaTypes,
    nullptr
} };

void KeyboardLayoutEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KeyboardLayoutEditor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->keyboardLayoutChanged(); break;
        case 1: _t->readOnlyChanged(); break;
        case 2: _t->selectedKeyChanged(); break;
        case 3: _t->zoomLevelChanged(); break;
        case 4: _t->setZoomLevel((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->clearSelection(); break;
        case 6: _t->validateSelection(); break;
        case 7: _t->createNewKey(); break;
        case 8: _t->createNewSpecialKey(); break;
        case 9: _t->deleteSelectedKey(); break;
        case 10: _t->setKeyGeometry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KeyboardLayoutEditor::*)()>(_a, &KeyboardLayoutEditor::keyboardLayoutChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardLayoutEditor::*)()>(_a, &KeyboardLayoutEditor::readOnlyChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardLayoutEditor::*)()>(_a, &KeyboardLayoutEditor::selectedKeyChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardLayoutEditor::*)()>(_a, &KeyboardLayoutEditor::zoomLevelChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KeyboardLayout**>(_v) = _t->keyboardLayout(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->readOnly(); break;
        case 2: *reinterpret_cast<AbstractKey**>(_v) = _t->selectedKey(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->zoomLevel(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setReadOnly(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setSelectedKey(*reinterpret_cast<AbstractKey**>(_v)); break;
        case 3: _t->setZoomLevel(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KeyboardLayoutEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KeyboardLayoutEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20KeyboardLayoutEditorE_t>.strings))
        return static_cast<void*>(this);
    return AbstractEditor::qt_metacast(_clname);
}

int KeyboardLayoutEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractEditor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KeyboardLayoutEditor::keyboardLayoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KeyboardLayoutEditor::readOnlyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KeyboardLayoutEditor::selectedKeyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KeyboardLayoutEditor::zoomLevelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
