/****************************************************************************
** Meta object code from reading C++ file 'keyboardlayout.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktouch-26.08.0/src/core/keyboardlayout.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keyboardlayout.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14KeyboardLayoutE_t {};
} // unnamed namespace

template <> constexpr inline auto KeyboardLayout::qt_create_metaobjectdata<qt_meta_tag_ZN14KeyboardLayoutE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KeyboardLayout",
        "associatedDataIndexKeyboardLayoutChanged",
        "",
        "widthChanged",
        "heightChanged",
        "referenceKeyChanged",
        "keyCountChanged",
        "onKeyGeometryChanged",
        "keyIndex",
        "key",
        "AbstractKey*",
        "index",
        "addKey",
        "insertKey",
        "removeKey",
        "clearKeys",
        "copyFrom",
        "KeyboardLayout*",
        "source",
        "allCharacters",
        "associatedDataIndexKeyboardLayout",
        "DataIndexKeyboardLayout*",
        "referenceKey",
        "width",
        "height",
        "keyCount"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'associatedDataIndexKeyboardLayoutChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'widthChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'heightChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'referenceKeyChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keyCountChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onKeyGeometryChanged'
        QtMocHelpers::SlotData<void(int)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Method 'key'
        QtMocHelpers::MethodData<AbstractKey *(int) const>(9, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::Int, 11 },
        }}),
        // Method 'keyIndex'
        QtMocHelpers::MethodData<int(AbstractKey *) const>(8, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 10, 9 },
        }}),
        // Method 'addKey'
        QtMocHelpers::MethodData<void(AbstractKey *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 9 },
        }}),
        // Method 'insertKey'
        QtMocHelpers::MethodData<void(int, AbstractKey *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { 0x80000000 | 10, 9 },
        }}),
        // Method 'removeKey'
        QtMocHelpers::MethodData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Method 'clearKeys'
        QtMocHelpers::MethodData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'copyFrom'
        QtMocHelpers::MethodData<void(KeyboardLayout *)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Method 'allCharacters'
        QtMocHelpers::MethodData<QString() const>(19, 2, QMC::AccessPublic, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'associatedDataIndexKeyboardLayout'
        QtMocHelpers::PropertyData<DataIndexKeyboardLayout*>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'referenceKey'
        QtMocHelpers::PropertyData<AbstractKey*>(22, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'width'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'height'
        QtMocHelpers::PropertyData<int>(24, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'keyCount'
        QtMocHelpers::PropertyData<int>(25, QMetaType::Int, QMC::DefaultPropertyFlags, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KeyboardLayout, qt_meta_tag_ZN14KeyboardLayoutE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KeyboardLayout::staticMetaObject = { {
    QMetaObject::SuperData::link<KeyboardLayoutBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KeyboardLayoutE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KeyboardLayoutE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14KeyboardLayoutE_t>.metaTypes,
    nullptr
} };

void KeyboardLayout::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KeyboardLayout *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->associatedDataIndexKeyboardLayoutChanged(); break;
        case 1: _t->widthChanged(); break;
        case 2: _t->heightChanged(); break;
        case 3: _t->referenceKeyChanged(); break;
        case 4: _t->keyCountChanged(); break;
        case 5: _t->onKeyGeometryChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: { AbstractKey* _r = _t->key((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<AbstractKey**>(_a[0]) = std::move(_r); }  break;
        case 7: { int _r = _t->keyIndex((*reinterpret_cast<std::add_pointer_t<AbstractKey*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->addKey((*reinterpret_cast<std::add_pointer_t<AbstractKey*>>(_a[1]))); break;
        case 9: _t->insertKey((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<AbstractKey*>>(_a[2]))); break;
        case 10: _t->removeKey((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->clearKeys(); break;
        case 12: _t->copyFrom((*reinterpret_cast<std::add_pointer_t<KeyboardLayout*>>(_a[1]))); break;
        case 13: { QString _r = _t->allCharacters();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KeyboardLayout* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KeyboardLayout::*)()>(_a, &KeyboardLayout::associatedDataIndexKeyboardLayoutChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardLayout::*)()>(_a, &KeyboardLayout::widthChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardLayout::*)()>(_a, &KeyboardLayout::heightChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardLayout::*)()>(_a, &KeyboardLayout::referenceKeyChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardLayout::*)()>(_a, &KeyboardLayout::keyCountChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<DataIndexKeyboardLayout**>(_v) = _t->associatedDataIndexKeyboardLayout(); break;
        case 1: *reinterpret_cast<AbstractKey**>(_v) = _t->referenceKey(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->width(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->height(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->keyCount(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAssociatedDataIndexKeyboardLayout(*reinterpret_cast<DataIndexKeyboardLayout**>(_v)); break;
        case 2: _t->setWidth(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setHeight(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KeyboardLayout::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KeyboardLayout::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KeyboardLayoutE_t>.strings))
        return static_cast<void*>(this);
    return KeyboardLayoutBase::qt_metacast(_clname);
}

int KeyboardLayout::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KeyboardLayoutBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void KeyboardLayout::associatedDataIndexKeyboardLayoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KeyboardLayout::widthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KeyboardLayout::heightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KeyboardLayout::referenceKeyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KeyboardLayout::keyCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
