/********************************************************************************
** Form generated from reading UI file 'keyboardlayouteditor.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KEYBOARDLAYOUTEDITOR_H
#define UI_KEYBOARDLAYOUTEDITOR_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include <kmessagewidget.h>
#include "editor/keyboardlayouteditorview.h"
#include "editor/keyboardlayoutpropertieswidget.h"

QT_BEGIN_NAMESPACE

class Ui_KeyboardLayoutEditor
{
public:
    QVBoxLayout *verticalLayout;
    KMessageWidget *m_messageWidget;
    QHBoxLayout *horizontalLayout_2;
    QToolButton *m_newKeyToolButton;
    QToolButton *m_newSpecialKeyToolButton;
    QToolButton *m_deleteKeyToolButton;
    QFrame *line;
    QToolButton *m_zoomOutToolButton;
    QSlider *m_zoomSlider;
    QLabel *m_zoomFactorLabel;
    QToolButton *m_zoomInToolButton;
    QSpacerItem *m_horizontalSpacer;
    QScrollArea *m_scrollArea;
    KeyboardLayoutEditorView *m_view;
    KeyboardLayoutPropertiesWidget *m_propertiesWidget;

    void setupUi(QWidget *KeyboardLayoutEditor)
    {
        if (KeyboardLayoutEditor->objectName().isEmpty())
            KeyboardLayoutEditor->setObjectName("KeyboardLayoutEditor");
        KeyboardLayoutEditor->resize(614, 480);
        verticalLayout = new QVBoxLayout(KeyboardLayoutEditor);
        verticalLayout->setObjectName("verticalLayout");
        m_messageWidget = new KMessageWidget(KeyboardLayoutEditor);
        m_messageWidget->setObjectName("m_messageWidget");

        verticalLayout->addWidget(m_messageWidget);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        m_newKeyToolButton = new QToolButton(KeyboardLayoutEditor);
        m_newKeyToolButton->setObjectName("m_newKeyToolButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        m_newKeyToolButton->setIcon(icon);
        m_newKeyToolButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
        m_newKeyToolButton->setAutoRaise(true);

        horizontalLayout_2->addWidget(m_newKeyToolButton);

        m_newSpecialKeyToolButton = new QToolButton(KeyboardLayoutEditor);
        m_newSpecialKeyToolButton->setObjectName("m_newSpecialKeyToolButton");
        m_newSpecialKeyToolButton->setIcon(icon);
        m_newSpecialKeyToolButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
        m_newSpecialKeyToolButton->setAutoRaise(true);

        horizontalLayout_2->addWidget(m_newSpecialKeyToolButton);

        m_deleteKeyToolButton = new QToolButton(KeyboardLayoutEditor);
        m_deleteKeyToolButton->setObjectName("m_deleteKeyToolButton");
        m_deleteKeyToolButton->setEnabled(false);
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("edit-delete")));
        m_deleteKeyToolButton->setIcon(icon1);
        m_deleteKeyToolButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
        m_deleteKeyToolButton->setAutoRaise(true);

        horizontalLayout_2->addWidget(m_deleteKeyToolButton);

        line = new QFrame(KeyboardLayoutEditor);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::VLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        horizontalLayout_2->addWidget(line);

        m_zoomOutToolButton = new QToolButton(KeyboardLayoutEditor);
        m_zoomOutToolButton->setObjectName("m_zoomOutToolButton");
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("zoom-out")));
        m_zoomOutToolButton->setIcon(icon2);
        m_zoomOutToolButton->setAutoRaise(true);

        horizontalLayout_2->addWidget(m_zoomOutToolButton);

        m_zoomSlider = new QSlider(KeyboardLayoutEditor);
        m_zoomSlider->setObjectName("m_zoomSlider");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_zoomSlider->sizePolicy().hasHeightForWidth());
        m_zoomSlider->setSizePolicy(sizePolicy);
        m_zoomSlider->setMinimumSize(QSize(100, 0));
        m_zoomSlider->setMinimum(-4);
        m_zoomSlider->setMaximum(4);
        m_zoomSlider->setPageStep(1);
        m_zoomSlider->setOrientation(Qt::Horizontal);

        horizontalLayout_2->addWidget(m_zoomSlider);

        m_zoomFactorLabel = new QLabel(KeyboardLayoutEditor);
        m_zoomFactorLabel->setObjectName("m_zoomFactorLabel");

        horizontalLayout_2->addWidget(m_zoomFactorLabel);

        m_zoomInToolButton = new QToolButton(KeyboardLayoutEditor);
        m_zoomInToolButton->setObjectName("m_zoomInToolButton");
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("zoom-in")));
        m_zoomInToolButton->setIcon(icon3);
        m_zoomInToolButton->setAutoRaise(true);

        horizontalLayout_2->addWidget(m_zoomInToolButton);

        m_horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(m_horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout_2);

        m_scrollArea = new QScrollArea(KeyboardLayoutEditor);
        m_scrollArea->setObjectName("m_scrollArea");
        m_scrollArea->setFrameShape(QFrame::NoFrame);
        m_view = new KeyboardLayoutEditorView();
        m_view->setObjectName("m_view");
        m_view->setGeometry(QRect(0, 0, 517, 287));
        m_scrollArea->setWidget(m_view);

        verticalLayout->addWidget(m_scrollArea);

        m_propertiesWidget = new KeyboardLayoutPropertiesWidget(KeyboardLayoutEditor);
        m_propertiesWidget->setObjectName("m_propertiesWidget");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_propertiesWidget->sizePolicy().hasHeightForWidth());
        m_propertiesWidget->setSizePolicy(sizePolicy1);

        verticalLayout->addWidget(m_propertiesWidget);

        QWidget::setTabOrder(m_newKeyToolButton, m_newSpecialKeyToolButton);
        QWidget::setTabOrder(m_newSpecialKeyToolButton, m_deleteKeyToolButton);
        QWidget::setTabOrder(m_deleteKeyToolButton, m_zoomOutToolButton);
        QWidget::setTabOrder(m_zoomOutToolButton, m_zoomSlider);
        QWidget::setTabOrder(m_zoomSlider, m_zoomInToolButton);

        retranslateUi(KeyboardLayoutEditor);

        QMetaObject::connectSlotsByName(KeyboardLayoutEditor);
    } // setupUi

    void retranslateUi(QWidget *KeyboardLayoutEditor)
    {
#if QT_CONFIG(tooltip)
        m_newKeyToolButton->setToolTip(tr2i18n("Create new normal key", nullptr));
#endif // QT_CONFIG(tooltip)
        m_newKeyToolButton->setText(tr2i18n("Normal Key", nullptr));
#if QT_CONFIG(tooltip)
        m_newSpecialKeyToolButton->setToolTip(tr2i18n("Create new special key", nullptr));
#endif // QT_CONFIG(tooltip)
        m_newSpecialKeyToolButton->setText(tr2i18n("Special Key", nullptr));
#if QT_CONFIG(tooltip)
        m_deleteKeyToolButton->setToolTip(tr2i18n("Delete selected key", nullptr));
#endif // QT_CONFIG(tooltip)
        m_deleteKeyToolButton->setText(tr2i18n("Delete", nullptr));
        m_zoomFactorLabel->setText(tr2i18n("100%", nullptr));
        (void)KeyboardLayoutEditor;
    } // retranslateUi

};

namespace Ui {
    class KeyboardLayoutEditor: public Ui_KeyboardLayoutEditor {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KEYBOARDLAYOUTEDITOR_H

