/********************************************************************************
** Form generated from reading UI file 'trainingconfigwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TRAININGCONFIGWIDGET_H
#define UI_TRAININGCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_TrainingConfigWidget
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout_2;
    QLabel *trainingLabel;
    QCheckBox *kcfg_EnforceTypingErrorCorrection;
    QCheckBox *kcfg_ShowKeyboard;
    QCheckBox *kcfg_ShowStatistics;
    QSpacerItem *verticalSpacer;
    QLabel *nextLineLabel;
    QRadioButton *kcfg_NextLineWithReturn;
    QRadioButton *kcfg_NextLineWithSpace;
    QSpacerItem *verticalSpacer_2;
    QGroupBox *groupBox;
    QFormLayout *formLayout;
    QLabel *requiredStrokesPerMinuteLabel;
    QSpinBox *kcfg_RequiredStrokesPerMinute;
    QLabel *requiredAccuracyLabel;
    QDoubleSpinBox *kcfg_RequiredAccuracy;
    QSpacerItem *verticalSpacer_3;

    void setupUi(QWidget *TrainingConfigWidget)
    {
        if (TrainingConfigWidget->objectName().isEmpty())
            TrainingConfigWidget->setObjectName("TrainingConfigWidget");
        TrainingConfigWidget->resize(374, 299);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(TrainingConfigWidget->sizePolicy().hasHeightForWidth());
        TrainingConfigWidget->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(TrainingConfigWidget);
        verticalLayout->setObjectName("verticalLayout");
        formLayout_2 = new QFormLayout();
        formLayout_2->setObjectName("formLayout_2");
        trainingLabel = new QLabel(TrainingConfigWidget);
        trainingLabel->setObjectName("trainingLabel");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, trainingLabel);

        kcfg_EnforceTypingErrorCorrection = new QCheckBox(TrainingConfigWidget);
        kcfg_EnforceTypingErrorCorrection->setObjectName("kcfg_EnforceTypingErrorCorrection");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_EnforceTypingErrorCorrection);

        kcfg_ShowKeyboard = new QCheckBox(TrainingConfigWidget);
        kcfg_ShowKeyboard->setObjectName("kcfg_ShowKeyboard");
        kcfg_ShowKeyboard->setMinimumSize(QSize(83, 0));

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_ShowKeyboard);

        kcfg_ShowStatistics = new QCheckBox(TrainingConfigWidget);
        kcfg_ShowStatistics->setObjectName("kcfg_ShowStatistics");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_ShowStatistics);

        verticalSpacer = new QSpacerItem(20, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        formLayout_2->setItem(3, QFormLayout::ItemRole::FieldRole, verticalSpacer);

        nextLineLabel = new QLabel(TrainingConfigWidget);
        nextLineLabel->setObjectName("nextLineLabel");

        formLayout_2->setWidget(4, QFormLayout::ItemRole::LabelRole, nextLineLabel);

        kcfg_NextLineWithReturn = new QRadioButton(TrainingConfigWidget);
        kcfg_NextLineWithReturn->setObjectName("kcfg_NextLineWithReturn");

        formLayout_2->setWidget(4, QFormLayout::ItemRole::FieldRole, kcfg_NextLineWithReturn);

        kcfg_NextLineWithSpace = new QRadioButton(TrainingConfigWidget);
        kcfg_NextLineWithSpace->setObjectName("kcfg_NextLineWithSpace");

        formLayout_2->setWidget(5, QFormLayout::ItemRole::FieldRole, kcfg_NextLineWithSpace);


        verticalLayout->addLayout(formLayout_2);

        verticalSpacer_2 = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_2);

        groupBox = new QGroupBox(TrainingConfigWidget);
        groupBox->setObjectName("groupBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy1);
        formLayout = new QFormLayout(groupBox);
        formLayout->setObjectName("formLayout");
        requiredStrokesPerMinuteLabel = new QLabel(groupBox);
        requiredStrokesPerMinuteLabel->setObjectName("requiredStrokesPerMinuteLabel");
        requiredStrokesPerMinuteLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, requiredStrokesPerMinuteLabel);

        kcfg_RequiredStrokesPerMinute = new QSpinBox(groupBox);
        kcfg_RequiredStrokesPerMinute->setObjectName("kcfg_RequiredStrokesPerMinute");
        kcfg_RequiredStrokesPerMinute->setMaximum(360);
        kcfg_RequiredStrokesPerMinute->setSingleStep(10);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_RequiredStrokesPerMinute);

        requiredAccuracyLabel = new QLabel(groupBox);
        requiredAccuracyLabel->setObjectName("requiredAccuracyLabel");
        requiredAccuracyLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, requiredAccuracyLabel);

        kcfg_RequiredAccuracy = new QDoubleSpinBox(groupBox);
        kcfg_RequiredAccuracy->setObjectName("kcfg_RequiredAccuracy");
        kcfg_RequiredAccuracy->setDecimals(1);
        kcfg_RequiredAccuracy->setMinimum(90.000000000000000);
        kcfg_RequiredAccuracy->setSingleStep(0.100000000000000);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_RequiredAccuracy);


        verticalLayout->addWidget(groupBox);

        verticalSpacer_3 = new QSpacerItem(20, 4, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_3);

#if QT_CONFIG(shortcut)
        requiredStrokesPerMinuteLabel->setBuddy(kcfg_RequiredStrokesPerMinute);
        requiredAccuracyLabel->setBuddy(kcfg_RequiredAccuracy);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_EnforceTypingErrorCorrection, kcfg_ShowKeyboard);
        QWidget::setTabOrder(kcfg_ShowKeyboard, kcfg_ShowStatistics);
        QWidget::setTabOrder(kcfg_ShowStatistics, kcfg_NextLineWithReturn);
        QWidget::setTabOrder(kcfg_NextLineWithReturn, kcfg_NextLineWithSpace);
        QWidget::setTabOrder(kcfg_NextLineWithSpace, kcfg_RequiredStrokesPerMinute);
        QWidget::setTabOrder(kcfg_RequiredStrokesPerMinute, kcfg_RequiredAccuracy);

        retranslateUi(TrainingConfigWidget);

        QMetaObject::connectSlotsByName(TrainingConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *TrainingConfigWidget)
    {
        trainingLabel->setText(tr2i18n("During training:", nullptr));
        kcfg_EnforceTypingErrorCorrection->setText(tr2i18n("Enforce correction of typing errors", nullptr));
        kcfg_ShowKeyboard->setText(tr2i18n("Show keyboard", nullptr));
        kcfg_ShowStatistics->setText(tr2i18n("Show real-time statistics", nullptr));
        nextLineLabel->setText(tr2i18n("Go to next line with:", nullptr));
        kcfg_NextLineWithReturn->setText(tr2i18n("Ret&urn", nullptr));
        kcfg_NextLineWithSpace->setText(tr2i18n("Spa&ce", nullptr));
        groupBox->setTitle(tr2i18n("Lesson unlocking limits", nullptr));
        requiredStrokesPerMinuteLabel->setText(tr2i18n("Minimum strokes &per minute:", nullptr));
        requiredAccuracyLabel->setText(tr2i18n("Minimum accuracy:", nullptr));
        kcfg_RequiredAccuracy->setSuffix(tr2i18n(" %", nullptr));
        (void)TrainingConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class TrainingConfigWidget: public Ui_TrainingConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TRAININGCONFIGWIDGET_H

