/********************************************************************************
** Form generated from reading UI file 'keyboardlayoutpropertieswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KEYBOARDLAYOUTPROPERTIESWIDGET_H
#define UI_KEYBOARDLAYOUTPROPERTIESWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTableView>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_KeyboardLayoutPropertiesWidget
{
public:
    QHBoxLayout *horizontalLayout_6;
    QStackedWidget *m_stackedWidget;
    QWidget *m_keyboardProperties;
    QHBoxLayout *horizontalLayout_3;
    QGroupBox *m_keyboardGroupBox;
    QHBoxLayout *horizontalLayout;
    QFormLayout *formLayout;
    QLabel *m_keyboardLayouttTitleLabel;
    KLineEdit *m_keyboardLayoutTitleLineEdit;
    QLabel *m_keyboardLayoutNameLabel;
    KLineEdit *m_keyboardLayoutNameEdit;
    QFormLayout *formLayout_2;
    QLabel *m_keyboardLayoutWidthLabel;
    QSpinBox *m_keyboardLayoutWidthSpinBox;
    QLabel *m_keyboardLayoutHeightLabel;
    QSpinBox *m_keyboardLayoutHeightSpinBox;
    QWidget *m_keyProperties;
    QHBoxLayout *horizontalLayout_5;
    QGroupBox *groupBox_2;
    QHBoxLayout *horizontalLayout_2;
    QFormLayout *formLayout_3;
    QLabel *label_5;
    QLabel *label_6;
    QSpinBox *m_keyLeftSpinBox;
    QSpinBox *m_keyTopSpinBox;
    QFormLayout *formLayout_4;
    QLabel *label_7;
    QSpinBox *m_keyWidthSpinBox;
    QLabel *label_8;
    QSpinBox *m_keyHeightSpinBox;
    QStackedWidget *m_subStackedWidget;
    QWidget *m_keyPropertiesSubWidget;
    QHBoxLayout *horizontalLayout_8;
    QGroupBox *groupBox_5;
    QFormLayout *formLayout_7;
    QLabel *m_keyFingerLabel;
    KComboBox *m_keyFingerComboBox;
    QLabel *m_keyHapticMarkerLabel;
    QCheckBox *m_keyHapticMarkerCheckBox;
    QGroupBox *groupBox_4;
    QHBoxLayout *horizontalLayout_4;
    QTableView *m_charactersView;
    QVBoxLayout *verticalLayout;
    QToolButton *m_addCharacterButton;
    QToolButton *m_removeCharacterButton;
    QSpacerItem *verticalSpacer;
    QWidget *m_specialKeyPropertiesSubWidget;
    QHBoxLayout *horizontalLayout_7;
    QGroupBox *groupBox_3;
    QFormLayout *formLayout_5;
    QLabel *m_specialKeyTypeLabel;
    KComboBox *m_specialKeyTypeComboBox;
    QLabel *m_specialKeyLabelLabel;
    KLineEdit *m_specialKeyLabelLineEdit;
    QLabel *m_specialKeyModifierIdLabel;
    KLineEdit *m_specialKeyModifierIdLineEdit;

    void setupUi(QWidget *KeyboardLayoutPropertiesWidget)
    {
        if (KeyboardLayoutPropertiesWidget->objectName().isEmpty())
            KeyboardLayoutPropertiesWidget->setObjectName("KeyboardLayoutPropertiesWidget");
        KeyboardLayoutPropertiesWidget->resize(562, 136);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(KeyboardLayoutPropertiesWidget->sizePolicy().hasHeightForWidth());
        KeyboardLayoutPropertiesWidget->setSizePolicy(sizePolicy);
        horizontalLayout_6 = new QHBoxLayout(KeyboardLayoutPropertiesWidget);
        horizontalLayout_6->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        m_stackedWidget = new QStackedWidget(KeyboardLayoutPropertiesWidget);
        m_stackedWidget->setObjectName("m_stackedWidget");
        m_keyboardProperties = new QWidget();
        m_keyboardProperties->setObjectName("m_keyboardProperties");
        horizontalLayout_3 = new QHBoxLayout(m_keyboardProperties);
        horizontalLayout_3->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        m_keyboardGroupBox = new QGroupBox(m_keyboardProperties);
        m_keyboardGroupBox->setObjectName("m_keyboardGroupBox");
        m_keyboardGroupBox->setFlat(false);
        horizontalLayout = new QHBoxLayout(m_keyboardGroupBox);
        horizontalLayout->setSpacing(15);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(-1, -1, -1, 0);
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        formLayout->setVerticalSpacing(0);
        m_keyboardLayouttTitleLabel = new QLabel(m_keyboardGroupBox);
        m_keyboardLayouttTitleLabel->setObjectName("m_keyboardLayouttTitleLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, m_keyboardLayouttTitleLabel);

        m_keyboardLayoutTitleLineEdit = new KLineEdit(m_keyboardGroupBox);
        m_keyboardLayoutTitleLineEdit->setObjectName("m_keyboardLayoutTitleLineEdit");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_keyboardLayoutTitleLineEdit->sizePolicy().hasHeightForWidth());
        m_keyboardLayoutTitleLineEdit->setSizePolicy(sizePolicy1);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, m_keyboardLayoutTitleLineEdit);

        m_keyboardLayoutNameLabel = new QLabel(m_keyboardGroupBox);
        m_keyboardLayoutNameLabel->setObjectName("m_keyboardLayoutNameLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, m_keyboardLayoutNameLabel);

        m_keyboardLayoutNameEdit = new KLineEdit(m_keyboardGroupBox);
        m_keyboardLayoutNameEdit->setObjectName("m_keyboardLayoutNameEdit");
        sizePolicy1.setHeightForWidth(m_keyboardLayoutNameEdit->sizePolicy().hasHeightForWidth());
        m_keyboardLayoutNameEdit->setSizePolicy(sizePolicy1);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, m_keyboardLayoutNameEdit);


        horizontalLayout->addLayout(formLayout);

        formLayout_2 = new QFormLayout();
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        formLayout_2->setVerticalSpacing(0);
        m_keyboardLayoutWidthLabel = new QLabel(m_keyboardGroupBox);
        m_keyboardLayoutWidthLabel->setObjectName("m_keyboardLayoutWidthLabel");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, m_keyboardLayoutWidthLabel);

        m_keyboardLayoutWidthSpinBox = new QSpinBox(m_keyboardGroupBox);
        m_keyboardLayoutWidthSpinBox->setObjectName("m_keyboardLayoutWidthSpinBox");
        sizePolicy1.setHeightForWidth(m_keyboardLayoutWidthSpinBox->sizePolicy().hasHeightForWidth());
        m_keyboardLayoutWidthSpinBox->setSizePolicy(sizePolicy1);
        m_keyboardLayoutWidthSpinBox->setMinimum(100);
        m_keyboardLayoutWidthSpinBox->setMaximum(10000);
        m_keyboardLayoutWidthSpinBox->setSingleStep(10);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, m_keyboardLayoutWidthSpinBox);

        m_keyboardLayoutHeightLabel = new QLabel(m_keyboardGroupBox);
        m_keyboardLayoutHeightLabel->setObjectName("m_keyboardLayoutHeightLabel");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, m_keyboardLayoutHeightLabel);

        m_keyboardLayoutHeightSpinBox = new QSpinBox(m_keyboardGroupBox);
        m_keyboardLayoutHeightSpinBox->setObjectName("m_keyboardLayoutHeightSpinBox");
        sizePolicy1.setHeightForWidth(m_keyboardLayoutHeightSpinBox->sizePolicy().hasHeightForWidth());
        m_keyboardLayoutHeightSpinBox->setSizePolicy(sizePolicy1);
        m_keyboardLayoutHeightSpinBox->setMinimum(100);
        m_keyboardLayoutHeightSpinBox->setMaximum(10000);
        m_keyboardLayoutHeightSpinBox->setSingleStep(10);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, m_keyboardLayoutHeightSpinBox);


        horizontalLayout->addLayout(formLayout_2);


        horizontalLayout_3->addWidget(m_keyboardGroupBox);

        m_stackedWidget->addWidget(m_keyboardProperties);
        m_keyProperties = new QWidget();
        m_keyProperties->setObjectName("m_keyProperties");
        horizontalLayout_5 = new QHBoxLayout(m_keyProperties);
        horizontalLayout_5->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        groupBox_2 = new QGroupBox(m_keyProperties);
        groupBox_2->setObjectName("groupBox_2");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(1);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(groupBox_2->sizePolicy().hasHeightForWidth());
        groupBox_2->setSizePolicy(sizePolicy2);
        groupBox_2->setFlat(false);
        horizontalLayout_2 = new QHBoxLayout(groupBox_2);
        horizontalLayout_2->setSpacing(15);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(-1, 0, -1, 0);
        formLayout_3 = new QFormLayout();
        formLayout_3->setObjectName("formLayout_3");
        formLayout_3->setHorizontalSpacing(0);
        formLayout_3->setVerticalSpacing(0);
        label_5 = new QLabel(groupBox_2);
        label_5->setObjectName("label_5");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, label_5);

        label_6 = new QLabel(groupBox_2);
        label_6->setObjectName("label_6");

        formLayout_3->setWidget(1, QFormLayout::ItemRole::LabelRole, label_6);

        m_keyLeftSpinBox = new QSpinBox(groupBox_2);
        m_keyLeftSpinBox->setObjectName("m_keyLeftSpinBox");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(m_keyLeftSpinBox->sizePolicy().hasHeightForWidth());
        m_keyLeftSpinBox->setSizePolicy(sizePolicy3);
        m_keyLeftSpinBox->setMaximum(1000);
        m_keyLeftSpinBox->setSingleStep(10);

        formLayout_3->setWidget(0, QFormLayout::ItemRole::FieldRole, m_keyLeftSpinBox);

        m_keyTopSpinBox = new QSpinBox(groupBox_2);
        m_keyTopSpinBox->setObjectName("m_keyTopSpinBox");
        sizePolicy3.setHeightForWidth(m_keyTopSpinBox->sizePolicy().hasHeightForWidth());
        m_keyTopSpinBox->setSizePolicy(sizePolicy3);
        m_keyTopSpinBox->setMaximum(1000);
        m_keyTopSpinBox->setSingleStep(10);

        formLayout_3->setWidget(1, QFormLayout::ItemRole::FieldRole, m_keyTopSpinBox);


        horizontalLayout_2->addLayout(formLayout_3);

        formLayout_4 = new QFormLayout();
        formLayout_4->setObjectName("formLayout_4");
        formLayout_4->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        formLayout_4->setHorizontalSpacing(0);
        formLayout_4->setVerticalSpacing(0);
        label_7 = new QLabel(groupBox_2);
        label_7->setObjectName("label_7");

        formLayout_4->setWidget(0, QFormLayout::ItemRole::LabelRole, label_7);

        m_keyWidthSpinBox = new QSpinBox(groupBox_2);
        m_keyWidthSpinBox->setObjectName("m_keyWidthSpinBox");
        sizePolicy3.setHeightForWidth(m_keyWidthSpinBox->sizePolicy().hasHeightForWidth());
        m_keyWidthSpinBox->setSizePolicy(sizePolicy3);
        m_keyWidthSpinBox->setMinimum(20);
        m_keyWidthSpinBox->setMaximum(10000);
        m_keyWidthSpinBox->setSingleStep(10);

        formLayout_4->setWidget(0, QFormLayout::ItemRole::FieldRole, m_keyWidthSpinBox);

        label_8 = new QLabel(groupBox_2);
        label_8->setObjectName("label_8");

        formLayout_4->setWidget(1, QFormLayout::ItemRole::LabelRole, label_8);

        m_keyHeightSpinBox = new QSpinBox(groupBox_2);
        m_keyHeightSpinBox->setObjectName("m_keyHeightSpinBox");
        sizePolicy3.setHeightForWidth(m_keyHeightSpinBox->sizePolicy().hasHeightForWidth());
        m_keyHeightSpinBox->setSizePolicy(sizePolicy3);
        m_keyHeightSpinBox->setMinimum(20);
        m_keyHeightSpinBox->setMaximum(10000);
        m_keyHeightSpinBox->setSingleStep(10);

        formLayout_4->setWidget(1, QFormLayout::ItemRole::FieldRole, m_keyHeightSpinBox);


        horizontalLayout_2->addLayout(formLayout_4);


        horizontalLayout_5->addWidget(groupBox_2);

        m_subStackedWidget = new QStackedWidget(m_keyProperties);
        m_subStackedWidget->setObjectName("m_subStackedWidget");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy4.setHorizontalStretch(2);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(m_subStackedWidget->sizePolicy().hasHeightForWidth());
        m_subStackedWidget->setSizePolicy(sizePolicy4);
        m_keyPropertiesSubWidget = new QWidget();
        m_keyPropertiesSubWidget->setObjectName("m_keyPropertiesSubWidget");
        horizontalLayout_8 = new QHBoxLayout(m_keyPropertiesSubWidget);
        horizontalLayout_8->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        groupBox_5 = new QGroupBox(m_keyPropertiesSubWidget);
        groupBox_5->setObjectName("groupBox_5");
        sizePolicy2.setHeightForWidth(groupBox_5->sizePolicy().hasHeightForWidth());
        groupBox_5->setSizePolicy(sizePolicy2);
        groupBox_5->setFlat(false);
        formLayout_7 = new QFormLayout(groupBox_5);
        formLayout_7->setObjectName("formLayout_7");
        formLayout_7->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        formLayout_7->setContentsMargins(-1, 0, -1, 0);
        m_keyFingerLabel = new QLabel(groupBox_5);
        m_keyFingerLabel->setObjectName("m_keyFingerLabel");

        formLayout_7->setWidget(0, QFormLayout::ItemRole::LabelRole, m_keyFingerLabel);

        m_keyFingerComboBox = new KComboBox(groupBox_5);
        m_keyFingerComboBox->addItem(QString());
        m_keyFingerComboBox->addItem(QString());
        m_keyFingerComboBox->addItem(QString());
        m_keyFingerComboBox->addItem(QString());
        m_keyFingerComboBox->addItem(QString());
        m_keyFingerComboBox->addItem(QString());
        m_keyFingerComboBox->addItem(QString());
        m_keyFingerComboBox->addItem(QString());
        m_keyFingerComboBox->setObjectName("m_keyFingerComboBox");
        sizePolicy3.setHeightForWidth(m_keyFingerComboBox->sizePolicy().hasHeightForWidth());
        m_keyFingerComboBox->setSizePolicy(sizePolicy3);

        formLayout_7->setWidget(0, QFormLayout::ItemRole::FieldRole, m_keyFingerComboBox);

        m_keyHapticMarkerLabel = new QLabel(groupBox_5);
        m_keyHapticMarkerLabel->setObjectName("m_keyHapticMarkerLabel");

        formLayout_7->setWidget(1, QFormLayout::ItemRole::LabelRole, m_keyHapticMarkerLabel);

        m_keyHapticMarkerCheckBox = new QCheckBox(groupBox_5);
        m_keyHapticMarkerCheckBox->setObjectName("m_keyHapticMarkerCheckBox");

        formLayout_7->setWidget(1, QFormLayout::ItemRole::FieldRole, m_keyHapticMarkerCheckBox);


        horizontalLayout_8->addWidget(groupBox_5);

        groupBox_4 = new QGroupBox(m_keyPropertiesSubWidget);
        groupBox_4->setObjectName("groupBox_4");
        sizePolicy2.setHeightForWidth(groupBox_4->sizePolicy().hasHeightForWidth());
        groupBox_4->setSizePolicy(sizePolicy2);
        horizontalLayout_4 = new QHBoxLayout(groupBox_4);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalLayout_4->setContentsMargins(-1, 0, -1, 0);
        m_charactersView = new QTableView(groupBox_4);
        m_charactersView->setObjectName("m_charactersView");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Ignored);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(m_charactersView->sizePolicy().hasHeightForWidth());
        m_charactersView->setSizePolicy(sizePolicy5);
        m_charactersView->setSelectionMode(QAbstractItemView::SingleSelection);
        m_charactersView->setSelectionBehavior(QAbstractItemView::SelectRows);
        m_charactersView->verticalHeader()->setVisible(false);

        horizontalLayout_4->addWidget(m_charactersView);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        m_addCharacterButton = new QToolButton(groupBox_4);
        m_addCharacterButton->setObjectName("m_addCharacterButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        m_addCharacterButton->setIcon(icon);

        verticalLayout->addWidget(m_addCharacterButton);

        m_removeCharacterButton = new QToolButton(groupBox_4);
        m_removeCharacterButton->setObjectName("m_removeCharacterButton");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("list-remove")));
        m_removeCharacterButton->setIcon(icon1);

        verticalLayout->addWidget(m_removeCharacterButton);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        horizontalLayout_4->addLayout(verticalLayout);


        horizontalLayout_8->addWidget(groupBox_4);

        m_subStackedWidget->addWidget(m_keyPropertiesSubWidget);
        m_specialKeyPropertiesSubWidget = new QWidget();
        m_specialKeyPropertiesSubWidget->setObjectName("m_specialKeyPropertiesSubWidget");
        horizontalLayout_7 = new QHBoxLayout(m_specialKeyPropertiesSubWidget);
        horizontalLayout_7->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        groupBox_3 = new QGroupBox(m_specialKeyPropertiesSubWidget);
        groupBox_3->setObjectName("groupBox_3");
        groupBox_3->setFlat(false);
        formLayout_5 = new QFormLayout(groupBox_3);
        formLayout_5->setObjectName("formLayout_5");
        formLayout_5->setContentsMargins(-1, 0, -1, -1);
        m_specialKeyTypeLabel = new QLabel(groupBox_3);
        m_specialKeyTypeLabel->setObjectName("m_specialKeyTypeLabel");

        formLayout_5->setWidget(0, QFormLayout::ItemRole::LabelRole, m_specialKeyTypeLabel);

        m_specialKeyTypeComboBox = new KComboBox(groupBox_3);
        m_specialKeyTypeComboBox->addItem(QString());
        m_specialKeyTypeComboBox->addItem(QString());
        m_specialKeyTypeComboBox->addItem(QString());
        m_specialKeyTypeComboBox->addItem(QString());
        m_specialKeyTypeComboBox->addItem(QString());
        m_specialKeyTypeComboBox->addItem(QString());
        m_specialKeyTypeComboBox->addItem(QString());
        m_specialKeyTypeComboBox->setObjectName("m_specialKeyTypeComboBox");
        sizePolicy1.setHeightForWidth(m_specialKeyTypeComboBox->sizePolicy().hasHeightForWidth());
        m_specialKeyTypeComboBox->setSizePolicy(sizePolicy1);

        formLayout_5->setWidget(0, QFormLayout::ItemRole::FieldRole, m_specialKeyTypeComboBox);

        m_specialKeyLabelLabel = new QLabel(groupBox_3);
        m_specialKeyLabelLabel->setObjectName("m_specialKeyLabelLabel");

        formLayout_5->setWidget(1, QFormLayout::ItemRole::LabelRole, m_specialKeyLabelLabel);

        m_specialKeyLabelLineEdit = new KLineEdit(groupBox_3);
        m_specialKeyLabelLineEdit->setObjectName("m_specialKeyLabelLineEdit");

        formLayout_5->setWidget(1, QFormLayout::ItemRole::FieldRole, m_specialKeyLabelLineEdit);

        m_specialKeyModifierIdLabel = new QLabel(groupBox_3);
        m_specialKeyModifierIdLabel->setObjectName("m_specialKeyModifierIdLabel");

        formLayout_5->setWidget(2, QFormLayout::ItemRole::LabelRole, m_specialKeyModifierIdLabel);

        m_specialKeyModifierIdLineEdit = new KLineEdit(groupBox_3);
        m_specialKeyModifierIdLineEdit->setObjectName("m_specialKeyModifierIdLineEdit");

        formLayout_5->setWidget(2, QFormLayout::ItemRole::FieldRole, m_specialKeyModifierIdLineEdit);


        horizontalLayout_7->addWidget(groupBox_3);

        m_subStackedWidget->addWidget(m_specialKeyPropertiesSubWidget);

        horizontalLayout_5->addWidget(m_subStackedWidget);

        m_stackedWidget->addWidget(m_keyProperties);

        horizontalLayout_6->addWidget(m_stackedWidget);

#if QT_CONFIG(shortcut)
        m_keyboardLayouttTitleLabel->setBuddy(m_keyboardLayoutTitleLineEdit);
        m_keyboardLayoutNameLabel->setBuddy(m_keyboardLayoutNameEdit);
        m_keyboardLayoutWidthLabel->setBuddy(m_keyboardLayoutWidthSpinBox);
        m_keyboardLayoutHeightLabel->setBuddy(m_keyboardLayoutHeightSpinBox);
        label_5->setBuddy(m_keyLeftSpinBox);
        label_6->setBuddy(m_keyTopSpinBox);
        label_7->setBuddy(m_keyWidthSpinBox);
        label_8->setBuddy(m_keyHeightSpinBox);
        m_keyFingerLabel->setBuddy(m_keyFingerComboBox);
        m_keyHapticMarkerLabel->setBuddy(m_keyHapticMarkerCheckBox);
        m_specialKeyTypeLabel->setBuddy(m_specialKeyTypeComboBox);
        m_specialKeyLabelLabel->setBuddy(m_specialKeyLabelLineEdit);
        m_specialKeyModifierIdLabel->setBuddy(m_specialKeyModifierIdLineEdit);
#endif // QT_CONFIG(shortcut)

        retranslateUi(KeyboardLayoutPropertiesWidget);

        m_stackedWidget->setCurrentIndex(1);
        m_subStackedWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(KeyboardLayoutPropertiesWidget);
    } // setupUi

    void retranslateUi(QWidget *KeyboardLayoutPropertiesWidget)
    {
        m_keyboardGroupBox->setTitle(tr2i18n("Keyboard", nullptr));
        m_keyboardLayouttTitleLabel->setText(tr2i18n("Title:", nullptr));
        m_keyboardLayoutNameLabel->setText(tr2i18n("Name:", nullptr));
        m_keyboardLayoutWidthLabel->setText(tr2i18n("Width:", nullptr));
        m_keyboardLayoutHeightLabel->setText(tr2i18n("Height:", nullptr));
        groupBox_2->setTitle(tr2i18n("Geometry", nullptr));
        label_5->setText(tr2i18n("Left:", nullptr));
        label_6->setText(tr2i18n("Top:", nullptr));
        label_7->setText(tr2i18n("Width:", nullptr));
        label_8->setText(tr2i18n("Height:", nullptr));
        groupBox_5->setTitle(tr2i18n("Key", nullptr));
        m_keyFingerLabel->setText(tr2i18n("Finger:", nullptr));
        m_keyFingerComboBox->setItemText(0, tr2i18n("Left little finger", nullptr));
        m_keyFingerComboBox->setItemText(1, tr2i18n("Left ring finger", nullptr));
        m_keyFingerComboBox->setItemText(2, tr2i18n("Left middle finger", nullptr));
        m_keyFingerComboBox->setItemText(3, tr2i18n("Left index finger", nullptr));
        m_keyFingerComboBox->setItemText(4, tr2i18n("Right index finger", nullptr));
        m_keyFingerComboBox->setItemText(5, tr2i18n("Right middle finger", nullptr));
        m_keyFingerComboBox->setItemText(6, tr2i18n("Right ring finger", nullptr));
        m_keyFingerComboBox->setItemText(7, tr2i18n("Right little finger", nullptr));

        m_keyHapticMarkerLabel->setText(tr2i18n("Haptic Marker:", nullptr));
        m_keyHapticMarkerCheckBox->setText(QString());
        groupBox_4->setTitle(tr2i18n("Characters", nullptr));
#if QT_CONFIG(tooltip)
        m_addCharacterButton->setToolTip(tr2i18n("Add new character", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        m_removeCharacterButton->setToolTip(tr2i18n("Remove character", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox_3->setTitle(tr2i18n("Key", nullptr));
        m_specialKeyTypeLabel->setText(tr2i18n("Type:", nullptr));
        m_specialKeyTypeComboBox->setItemText(0, tr2i18n("Tab", nullptr));
        m_specialKeyTypeComboBox->setItemText(1, tr2i18n("Capslock", nullptr));
        m_specialKeyTypeComboBox->setItemText(2, tr2i18n("Shift", nullptr));
        m_specialKeyTypeComboBox->setItemText(3, tr2i18n("Backspace", nullptr));
        m_specialKeyTypeComboBox->setItemText(4, tr2i18n("Return", nullptr));
        m_specialKeyTypeComboBox->setItemText(5, tr2i18n("Space", nullptr));
        m_specialKeyTypeComboBox->setItemText(6, tr2i18n("Other", nullptr));

        m_specialKeyLabelLabel->setText(tr2i18n("Label:", nullptr));
        m_specialKeyModifierIdLabel->setText(tr2i18n("Modifier ID:", nullptr));
        (void)KeyboardLayoutPropertiesWidget;
    } // retranslateUi

};

namespace Ui {
    class KeyboardLayoutPropertiesWidget: public Ui_KeyboardLayoutPropertiesWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KEYBOARDLAYOUTPROPERTIESWIDGET_H

