/********************************************************************************
** Form generated from reading UI file 'newkeyboardlayoutwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NEWKEYBOARDLAYOUTWIDGET_H
#define UI_NEWKEYBOARDLAYOUTWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include <kmessagewidget.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_NewKeyboardLayoutWidget
{
public:
    QVBoxLayout *verticalLayout;
    KMessageWidget *m_messageWidget;
    QFormLayout *formLayout;
    QLabel *m_nameLabel;
    QHBoxLayout *horizontalLayout;
    KLineEdit *m_nameLineEdit;
    QToolButton *m_pasteCurrentNameButton;
    QLabel *m_titleLabel;
    KLineEdit *m_titleLineEdit;

    void setupUi(QWidget *NewKeyboardLayoutWidget)
    {
        if (NewKeyboardLayoutWidget->objectName().isEmpty())
            NewKeyboardLayoutWidget->setObjectName("NewKeyboardLayoutWidget");
        NewKeyboardLayoutWidget->resize(256, 78);
        verticalLayout = new QVBoxLayout(NewKeyboardLayoutWidget);
        verticalLayout->setObjectName("verticalLayout");
        m_messageWidget = new KMessageWidget(NewKeyboardLayoutWidget);
        m_messageWidget->setObjectName("m_messageWidget");

        verticalLayout->addWidget(m_messageWidget);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        m_nameLabel = new QLabel(NewKeyboardLayoutWidget);
        m_nameLabel->setObjectName("m_nameLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, m_nameLabel);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        m_nameLineEdit = new KLineEdit(NewKeyboardLayoutWidget);
        m_nameLineEdit->setObjectName("m_nameLineEdit");

        horizontalLayout->addWidget(m_nameLineEdit);

        m_pasteCurrentNameButton = new QToolButton(NewKeyboardLayoutWidget);
        m_pasteCurrentNameButton->setObjectName("m_pasteCurrentNameButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("tools-wizard")));
        m_pasteCurrentNameButton->setIcon(icon);

        horizontalLayout->addWidget(m_pasteCurrentNameButton);


        formLayout->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        m_titleLabel = new QLabel(NewKeyboardLayoutWidget);
        m_titleLabel->setObjectName("m_titleLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, m_titleLabel);

        m_titleLineEdit = new KLineEdit(NewKeyboardLayoutWidget);
        m_titleLineEdit->setObjectName("m_titleLineEdit");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, m_titleLineEdit);


        verticalLayout->addLayout(formLayout);

#if QT_CONFIG(shortcut)
        m_nameLabel->setBuddy(m_nameLineEdit);
        m_titleLabel->setBuddy(m_titleLineEdit);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(m_titleLineEdit, m_nameLineEdit);
        QWidget::setTabOrder(m_nameLineEdit, m_pasteCurrentNameButton);

        retranslateUi(NewKeyboardLayoutWidget);

        QMetaObject::connectSlotsByName(NewKeyboardLayoutWidget);
    } // setupUi

    void retranslateUi(QWidget *NewKeyboardLayoutWidget)
    {
        m_nameLabel->setText(tr2i18n("Name:", nullptr));
#if QT_CONFIG(tooltip)
        m_pasteCurrentNameButton->setToolTip(tr2i18n("Paste current system keyboard layout name", nullptr));
#endif // QT_CONFIG(tooltip)
        m_titleLabel->setText(tr2i18n("Title:", nullptr));
        (void)NewKeyboardLayoutWidget;
    } // retranslateUi

};

namespace Ui {
    class NewKeyboardLayoutWidget: public Ui_NewKeyboardLayoutWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NEWKEYBOARDLAYOUTWIDGET_H

