/****************************************************************************
** Meta object code from reading C++ file 'categorizedresourcesortfilterproxymodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktouch-26.08.0/src/models/categorizedresourcesortfilterproxymodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'categorizedresourcesortfilterproxymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN39CategorizedResourceSortFilterProxyModelE_t {};
} // unnamed namespace

template <> constexpr inline auto CategorizedResourceSortFilterProxyModel::qt_create_metaobjectdata<qt_meta_tag_ZN39CategorizedResourceSortFilterProxyModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CategorizedResourceSortFilterProxyModel",
        "resourceTypeFilterChanged",
        "",
        "keyboardLayoutNameFilterChanged",
        "invertedKeyboardLayoutNameFilterChanged",
        "resourceModelChanged",
        "resourceTypeFilter",
        "ResourceModel::ResourceItemTypes",
        "keyboardLayoutNameFilter",
        "invertedKeyboardLayoutNameFilter",
        "resourceModel",
        "ResourceModel*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'resourceTypeFilterChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keyboardLayoutNameFilterChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'invertedKeyboardLayoutNameFilterChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resourceModelChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'resourceTypeFilter'
        QtMocHelpers::PropertyData<ResourceModel::ResourceItemTypes>(6, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'keyboardLayoutNameFilter'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'invertedKeyboardLayoutNameFilter'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'resourceModel'
        QtMocHelpers::PropertyData<ResourceModel*>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CategorizedResourceSortFilterProxyModel, qt_meta_tag_ZN39CategorizedResourceSortFilterProxyModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN39CategorizedResourceSortFilterProxyModelE[] = {
    QMetaObject::SuperData::link<ResourceModel::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject CategorizedResourceSortFilterProxyModel::staticMetaObject = { {
    QMetaObject::SuperData::link<KCategorizedSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN39CategorizedResourceSortFilterProxyModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN39CategorizedResourceSortFilterProxyModelE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN39CategorizedResourceSortFilterProxyModelE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN39CategorizedResourceSortFilterProxyModelE_t>.metaTypes,
    nullptr
} };

void CategorizedResourceSortFilterProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CategorizedResourceSortFilterProxyModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->resourceTypeFilterChanged(); break;
        case 1: _t->keyboardLayoutNameFilterChanged(); break;
        case 2: _t->invertedKeyboardLayoutNameFilterChanged(); break;
        case 3: _t->resourceModelChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CategorizedResourceSortFilterProxyModel::*)()>(_a, &CategorizedResourceSortFilterProxyModel::resourceTypeFilterChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CategorizedResourceSortFilterProxyModel::*)()>(_a, &CategorizedResourceSortFilterProxyModel::keyboardLayoutNameFilterChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CategorizedResourceSortFilterProxyModel::*)()>(_a, &CategorizedResourceSortFilterProxyModel::invertedKeyboardLayoutNameFilterChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CategorizedResourceSortFilterProxyModel::*)()>(_a, &CategorizedResourceSortFilterProxyModel::resourceModelChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ResourceModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<ResourceModel::ResourceItemTypes*>(_v) = _t->resourceTypeFilter(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->keyboardLayoutNameFilter(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->invertedKeyboardLayoutNameFilter(); break;
        case 3: *reinterpret_cast<ResourceModel**>(_v) = _t->resourceModel(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setResourceTypeFilter(*reinterpret_cast<ResourceModel::ResourceItemTypes*>(_v)); break;
        case 1: _t->setKeyboardLayoutNameFilter(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setInvertedKeyboardLayoutNameFilter(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setResourceModel(*reinterpret_cast<ResourceModel**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *CategorizedResourceSortFilterProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CategorizedResourceSortFilterProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN39CategorizedResourceSortFilterProxyModelE_t>.strings))
        return static_cast<void*>(this);
    return KCategorizedSortFilterProxyModel::qt_metacast(_clname);
}

int CategorizedResourceSortFilterProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KCategorizedSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void CategorizedResourceSortFilterProxyModel::resourceTypeFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void CategorizedResourceSortFilterProxyModel::keyboardLayoutNameFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void CategorizedResourceSortFilterProxyModel::invertedKeyboardLayoutNameFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void CategorizedResourceSortFilterProxyModel::resourceModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
