/****************************************************************************
** Meta object code from reading C++ file 'traininglinecore.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktouch-26.08.0/src/declarativeitems/traininglinecore.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'traininglinecore.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16TrainingLineCoreE_t {};
} // unnamed namespace

template <> constexpr inline auto TrainingLineCore::qt_create_metaobjectdata<qt_meta_tag_ZN16TrainingLineCoreE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TrainingLineCore",
        "activeChanged",
        "",
        "cursorItemChanged",
        "trainingStatsChanged",
        "referenceLineChanged",
        "actualLineChanged",
        "preeditStringChanged",
        "hintKeyChanged",
        "done",
        "reset",
        "active",
        "cursorItem",
        "QQuickItem*",
        "trainingStats",
        "TrainingStats*",
        "referenceLine",
        "actualLine",
        "preeditString",
        "isCorrect",
        "nextCharacter",
        "hintKey"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'activeChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cursorItemChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trainingStatsChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'referenceLineChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'actualLineChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'preeditStringChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hintKeyChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'done'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reset'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'active'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'cursorItem'
        QtMocHelpers::PropertyData<QQuickItem*>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'trainingStats'
        QtMocHelpers::PropertyData<TrainingStats*>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'referenceLine'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'actualLine'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'preeditString'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'isCorrect'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'nextCharacter'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'hintKey'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags, 6),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TrainingLineCore, qt_meta_tag_ZN16TrainingLineCoreE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TrainingLineCore::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16TrainingLineCoreE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16TrainingLineCoreE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16TrainingLineCoreE_t>.metaTypes,
    nullptr
} };

void TrainingLineCore::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TrainingLineCore *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->activeChanged(); break;
        case 1: _t->cursorItemChanged(); break;
        case 2: _t->trainingStatsChanged(); break;
        case 3: _t->referenceLineChanged(); break;
        case 4: _t->actualLineChanged(); break;
        case 5: _t->preeditStringChanged(); break;
        case 6: _t->hintKeyChanged(); break;
        case 7: _t->done(); break;
        case 8: _t->reset(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TrainingLineCore::*)()>(_a, &TrainingLineCore::activeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrainingLineCore::*)()>(_a, &TrainingLineCore::cursorItemChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrainingLineCore::*)()>(_a, &TrainingLineCore::trainingStatsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrainingLineCore::*)()>(_a, &TrainingLineCore::referenceLineChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrainingLineCore::*)()>(_a, &TrainingLineCore::actualLineChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrainingLineCore::*)()>(_a, &TrainingLineCore::preeditStringChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrainingLineCore::*)()>(_a, &TrainingLineCore::hintKeyChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrainingLineCore::*)()>(_a, &TrainingLineCore::done, 7))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->active(); break;
        case 1: *reinterpret_cast<QQuickItem**>(_v) = _t->cursorItem(); break;
        case 2: *reinterpret_cast<TrainingStats**>(_v) = _t->trainingStats(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->referenceLine(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->actualLine(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->preeditString(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isCorrect(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->nextCharacter(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->hintKey(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setActive(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setCursorItem(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 2: _t->setTrainingStats(*reinterpret_cast<TrainingStats**>(_v)); break;
        case 3: _t->setReferenceLine(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *TrainingLineCore::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TrainingLineCore::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16TrainingLineCoreE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int TrainingLineCore::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void TrainingLineCore::activeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TrainingLineCore::cursorItemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TrainingLineCore::trainingStatsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void TrainingLineCore::referenceLineChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void TrainingLineCore::actualLineChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void TrainingLineCore::preeditStringChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void TrainingLineCore::hintKeyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void TrainingLineCore::done()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
