/****************************************************************************
** Meta object code from reading C++ file 'keyboardlayoutpropertieswidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktouch-26.08.0/src/editor/keyboardlayoutpropertieswidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keyboardlayoutpropertieswidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN30KeyboardLayoutPropertiesWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto KeyboardLayoutPropertiesWidget::qt_create_metaobjectdata<qt_meta_tag_ZN30KeyboardLayoutPropertiesWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KeyboardLayoutPropertiesWidget",
        "setKeyboardLayoutTitle",
        "",
        "title",
        "setKeyboardLayoutName",
        "name",
        "setKeyboardLayoutSize",
        "QSize",
        "size",
        "setKeyGeometry",
        "QRect",
        "rect",
        "setKeyFingerIndex",
        "fingerIndex",
        "setKeyHasHapticMarker",
        "hasHapticMarker",
        "addCharacter",
        "removeCharacter",
        "setSpecialKeyType",
        "type",
        "setSpecialKeyLabel",
        "label",
        "setSpecialKeyModifierId",
        "id",
        "updateKeyboardLayoutTitle",
        "updateKeyboardLayoutName",
        "updateKeyboardLayoutWidth",
        "updateKeyboardLayoutHeight",
        "updateKeyLeft",
        "updateKeyTop",
        "updateKeyWidth",
        "updateKeyHeight",
        "resetKeyGeometry",
        "AbstractKey*",
        "key",
        "updateKeyFingerIndex",
        "updateKeyHasHapticMarker",
        "updateSpecialKeyType",
        "updateSpecialKeyLabel",
        "updateSpecialKeyModifierId",
        "onKeyboardLayoutWidthChanged",
        "width",
        "onKeyboardLayoutHeightChanged",
        "height",
        "onKeyLeftChanged",
        "left",
        "onKeyTopChanged",
        "top",
        "onKeyWidthChanged",
        "onKeyHeightChanged",
        "onFingerIndexChanged",
        "onCharacterSelected",
        "onSpecialKeyTypeChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'setKeyboardLayoutTitle'
        QtMocHelpers::SlotData<void(const QString &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'setKeyboardLayoutName'
        QtMocHelpers::SlotData<void(const QString &)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'setKeyboardLayoutSize'
        QtMocHelpers::SlotData<void(const QSize &)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'setKeyGeometry'
        QtMocHelpers::SlotData<void(const QRect &)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'setKeyFingerIndex'
        QtMocHelpers::SlotData<void(int)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Slot 'setKeyHasHapticMarker'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'addCharacter'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removeCharacter'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setSpecialKeyType'
        QtMocHelpers::SlotData<void(int)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'setSpecialKeyLabel'
        QtMocHelpers::SlotData<void(const QString &)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'setSpecialKeyModifierId'
        QtMocHelpers::SlotData<void(const QString &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
        // Slot 'updateKeyboardLayoutTitle'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateKeyboardLayoutName'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateKeyboardLayoutWidth'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateKeyboardLayoutHeight'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateKeyLeft'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateKeyTop'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateKeyWidth'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateKeyHeight'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'resetKeyGeometry'
        QtMocHelpers::SlotData<void(AbstractKey *)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Slot 'updateKeyFingerIndex'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateKeyHasHapticMarker'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateSpecialKeyType'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateSpecialKeyLabel'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateSpecialKeyModifierId'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onKeyboardLayoutWidthChanged'
        QtMocHelpers::SlotData<void(int)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 41 },
        }}),
        // Slot 'onKeyboardLayoutHeightChanged'
        QtMocHelpers::SlotData<void(int)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 43 },
        }}),
        // Slot 'onKeyLeftChanged'
        QtMocHelpers::SlotData<void(int)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 45 },
        }}),
        // Slot 'onKeyTopChanged'
        QtMocHelpers::SlotData<void(int)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 47 },
        }}),
        // Slot 'onKeyWidthChanged'
        QtMocHelpers::SlotData<void(int)>(48, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 41 },
        }}),
        // Slot 'onKeyHeightChanged'
        QtMocHelpers::SlotData<void(int)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 43 },
        }}),
        // Slot 'onFingerIndexChanged'
        QtMocHelpers::SlotData<void(int)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Slot 'onCharacterSelected'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSpecialKeyTypeChanged'
        QtMocHelpers::SlotData<void(int)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KeyboardLayoutPropertiesWidget, qt_meta_tag_ZN30KeyboardLayoutPropertiesWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KeyboardLayoutPropertiesWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30KeyboardLayoutPropertiesWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30KeyboardLayoutPropertiesWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN30KeyboardLayoutPropertiesWidgetE_t>.metaTypes,
    nullptr
} };

void KeyboardLayoutPropertiesWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KeyboardLayoutPropertiesWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setKeyboardLayoutTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->setKeyboardLayoutName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->setKeyboardLayoutSize((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        case 3: _t->setKeyGeometry((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 4: _t->setKeyFingerIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->setKeyHasHapticMarker((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->addCharacter(); break;
        case 7: _t->removeCharacter(); break;
        case 8: _t->setSpecialKeyType((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->setSpecialKeyLabel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->setSpecialKeyModifierId((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->updateKeyboardLayoutTitle(); break;
        case 12: _t->updateKeyboardLayoutName(); break;
        case 13: _t->updateKeyboardLayoutWidth(); break;
        case 14: _t->updateKeyboardLayoutHeight(); break;
        case 15: _t->updateKeyLeft(); break;
        case 16: _t->updateKeyTop(); break;
        case 17: _t->updateKeyWidth(); break;
        case 18: _t->updateKeyHeight(); break;
        case 19: _t->resetKeyGeometry((*reinterpret_cast<std::add_pointer_t<AbstractKey*>>(_a[1]))); break;
        case 20: _t->updateKeyFingerIndex(); break;
        case 21: _t->updateKeyHasHapticMarker(); break;
        case 22: _t->updateSpecialKeyType(); break;
        case 23: _t->updateSpecialKeyLabel(); break;
        case 24: _t->updateSpecialKeyModifierId(); break;
        case 25: _t->onKeyboardLayoutWidthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->onKeyboardLayoutHeightChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 27: _t->onKeyLeftChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 28: _t->onKeyTopChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 29: _t->onKeyWidthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 30: _t->onKeyHeightChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 31: _t->onFingerIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 32: _t->onCharacterSelected(); break;
        case 33: _t->onSpecialKeyTypeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *KeyboardLayoutPropertiesWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KeyboardLayoutPropertiesWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30KeyboardLayoutPropertiesWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KeyboardLayoutPropertiesWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 34)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 34;
    }
    return _id;
}
QT_WARNING_POP
