/****************************************************************************
** Meta object code from reading C++ file 'dataindex.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktouch-26.08.0/src/core/dataindex.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dataindex.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9DataIndexE_t {};
} // unnamed namespace

template <> constexpr inline auto DataIndex::qt_create_metaobjectdata<qt_meta_tag_ZN9DataIndexE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DataIndex",
        "courseCountChanged",
        "",
        "keyboardLayoutCountChanged",
        "courseAboutToBeAdded",
        "DataIndexCourse*",
        "course",
        "index",
        "courseAdded",
        "coursesAboutToBeRemoved",
        "first",
        "last",
        "coursesRemoved",
        "keyboardLayoutAboutToBeAdded",
        "DataIndexKeyboardLayout*",
        "keyboardLayout",
        "keyboardLayoutAdded",
        "keyboardLayoutsAboutToBeRemoved",
        "keyboardLayoutsRemoved",
        "addCourse",
        "removeCourse",
        "clearCourses",
        "addKeyboardLayout",
        "removeKeyboardLayout",
        "clearKeyboardLayouts",
        "courseCount",
        "keyboardLayoutCount",
        "Source",
        "BuiltInResource",
        "UserResource"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'courseCountChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keyboardLayoutCountChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'courseAboutToBeAdded'
        QtMocHelpers::SignalData<void(DataIndexCourse *, int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::Int, 7 },
        }}),
        // Signal 'courseAdded'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'coursesAboutToBeRemoved'
        QtMocHelpers::SignalData<void(int, int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
        }}),
        // Signal 'coursesRemoved'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keyboardLayoutAboutToBeAdded'
        QtMocHelpers::SignalData<void(DataIndexKeyboardLayout *, int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { QMetaType::Int, 7 },
        }}),
        // Signal 'keyboardLayoutAdded'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keyboardLayoutsAboutToBeRemoved'
        QtMocHelpers::SignalData<void(int, int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
        }}),
        // Signal 'keyboardLayoutsRemoved'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'course'
        QtMocHelpers::MethodData<DataIndexCourse *(int) const>(6, 2, QMC::AccessPublic, 0x80000000 | 5, {{
            { QMetaType::Int, 7 },
        }}),
        // Method 'addCourse'
        QtMocHelpers::MethodData<void(DataIndexCourse *)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'removeCourse'
        QtMocHelpers::MethodData<void(int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Method 'clearCourses'
        QtMocHelpers::MethodData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'keyboardLayout'
        QtMocHelpers::MethodData<DataIndexKeyboardLayout *(int) const>(15, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::Int, 7 },
        }}),
        // Method 'addKeyboardLayout'
        QtMocHelpers::MethodData<void(DataIndexKeyboardLayout *)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Method 'removeKeyboardLayout'
        QtMocHelpers::MethodData<void(int)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Method 'clearKeyboardLayouts'
        QtMocHelpers::MethodData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'courseCount'
        QtMocHelpers::PropertyData<int>(25, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'keyboardLayoutCount'
        QtMocHelpers::PropertyData<int>(26, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Source'
        QtMocHelpers::EnumData<enum Source>(27, 27, QMC::EnumFlags{}).add({
            {   28, Source::BuiltInResource },
            {   29, Source::UserResource },
        }),
    };
    return QtMocHelpers::metaObjectData<DataIndex, qt_meta_tag_ZN9DataIndexE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DataIndex::staticMetaObject = { {
    QMetaObject::SuperData::link<Resource::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DataIndexE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DataIndexE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9DataIndexE_t>.metaTypes,
    nullptr
} };

void DataIndex::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DataIndex *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->courseCountChanged(); break;
        case 1: _t->keyboardLayoutCountChanged(); break;
        case 2: _t->courseAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<DataIndexCourse*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: _t->courseAdded(); break;
        case 4: _t->coursesAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->coursesRemoved(); break;
        case 6: _t->keyboardLayoutAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<DataIndexKeyboardLayout*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 7: _t->keyboardLayoutAdded(); break;
        case 8: _t->keyboardLayoutsAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 9: _t->keyboardLayoutsRemoved(); break;
        case 10: { DataIndexCourse* _r = _t->course((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<DataIndexCourse**>(_a[0]) = std::move(_r); }  break;
        case 11: _t->addCourse((*reinterpret_cast<std::add_pointer_t<DataIndexCourse*>>(_a[1]))); break;
        case 12: _t->removeCourse((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->clearCourses(); break;
        case 14: { DataIndexKeyboardLayout* _r = _t->keyboardLayout((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<DataIndexKeyboardLayout**>(_a[0]) = std::move(_r); }  break;
        case 15: _t->addKeyboardLayout((*reinterpret_cast<std::add_pointer_t<DataIndexKeyboardLayout*>>(_a[1]))); break;
        case 16: _t->removeKeyboardLayout((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->clearKeyboardLayouts(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataIndexCourse* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataIndexKeyboardLayout* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataIndexCourse* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataIndexKeyboardLayout* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DataIndex::*)()>(_a, &DataIndex::courseCountChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataIndex::*)()>(_a, &DataIndex::keyboardLayoutCountChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataIndex::*)(DataIndexCourse * , int )>(_a, &DataIndex::courseAboutToBeAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataIndex::*)()>(_a, &DataIndex::courseAdded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataIndex::*)(int , int )>(_a, &DataIndex::coursesAboutToBeRemoved, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataIndex::*)()>(_a, &DataIndex::coursesRemoved, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataIndex::*)(DataIndexKeyboardLayout * , int )>(_a, &DataIndex::keyboardLayoutAboutToBeAdded, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataIndex::*)()>(_a, &DataIndex::keyboardLayoutAdded, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataIndex::*)(int , int )>(_a, &DataIndex::keyboardLayoutsAboutToBeRemoved, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataIndex::*)()>(_a, &DataIndex::keyboardLayoutsRemoved, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->courseCount(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->keyboardLayoutCount(); break;
        default: break;
        }
    }
}

const QMetaObject *DataIndex::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DataIndex::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DataIndexE_t>.strings))
        return static_cast<void*>(this);
    return Resource::qt_metacast(_clname);
}

int DataIndex::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Resource::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void DataIndex::courseCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DataIndex::keyboardLayoutCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DataIndex::courseAboutToBeAdded(DataIndexCourse * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void DataIndex::courseAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DataIndex::coursesAboutToBeRemoved(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void DataIndex::coursesRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DataIndex::keyboardLayoutAboutToBeAdded(DataIndexKeyboardLayout * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void DataIndex::keyboardLayoutAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DataIndex::keyboardLayoutsAboutToBeRemoved(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void DataIndex::keyboardLayoutsRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
namespace {
struct qt_meta_tag_ZN15DataIndexCourseE_t {};
} // unnamed namespace

template <> constexpr inline auto DataIndexCourse::qt_create_metaobjectdata<qt_meta_tag_ZN15DataIndexCourseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DataIndexCourse",
        "pathChanged",
        "",
        "sourceChanged",
        "path",
        "source",
        "DataIndex::Source"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'pathChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'path'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'source'
        QtMocHelpers::PropertyData<DataIndex::Source>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DataIndexCourse, qt_meta_tag_ZN15DataIndexCourseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN15DataIndexCourseE[] = {
    QMetaObject::SuperData::link<DataIndex::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject DataIndexCourse::staticMetaObject = { {
    QMetaObject::SuperData::link<CourseBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DataIndexCourseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DataIndexCourseE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN15DataIndexCourseE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15DataIndexCourseE_t>.metaTypes,
    nullptr
} };

void DataIndexCourse::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DataIndexCourse *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->pathChanged(); break;
        case 1: _t->sourceChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DataIndexCourse::*)()>(_a, &DataIndexCourse::pathChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataIndexCourse::*)()>(_a, &DataIndexCourse::sourceChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->path(); break;
        case 1: *reinterpret_cast<DataIndex::Source*>(_v) = _t->source(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPath(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setSource(*reinterpret_cast<DataIndex::Source*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DataIndexCourse::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DataIndexCourse::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DataIndexCourseE_t>.strings))
        return static_cast<void*>(this);
    return CourseBase::qt_metacast(_clname);
}

int DataIndexCourse::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = CourseBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void DataIndexCourse::pathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DataIndexCourse::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN23DataIndexKeyboardLayoutE_t {};
} // unnamed namespace

template <> constexpr inline auto DataIndexKeyboardLayout::qt_create_metaobjectdata<qt_meta_tag_ZN23DataIndexKeyboardLayoutE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DataIndexKeyboardLayout",
        "pathChanged",
        "",
        "sourceChanged",
        "path",
        "source",
        "DataIndex::Source"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'pathChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'path'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'source'
        QtMocHelpers::PropertyData<DataIndex::Source>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DataIndexKeyboardLayout, qt_meta_tag_ZN23DataIndexKeyboardLayoutE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN23DataIndexKeyboardLayoutE[] = {
    QMetaObject::SuperData::link<DataIndex::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject DataIndexKeyboardLayout::staticMetaObject = { {
    QMetaObject::SuperData::link<KeyboardLayoutBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23DataIndexKeyboardLayoutE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23DataIndexKeyboardLayoutE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN23DataIndexKeyboardLayoutE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23DataIndexKeyboardLayoutE_t>.metaTypes,
    nullptr
} };

void DataIndexKeyboardLayout::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DataIndexKeyboardLayout *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->pathChanged(); break;
        case 1: _t->sourceChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DataIndexKeyboardLayout::*)()>(_a, &DataIndexKeyboardLayout::pathChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataIndexKeyboardLayout::*)()>(_a, &DataIndexKeyboardLayout::sourceChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->path(); break;
        case 1: *reinterpret_cast<DataIndex::Source*>(_v) = _t->source(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPath(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setSource(*reinterpret_cast<DataIndex::Source*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DataIndexKeyboardLayout::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DataIndexKeyboardLayout::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23DataIndexKeyboardLayoutE_t>.strings))
        return static_cast<void*>(this);
    return KeyboardLayoutBase::qt_metacast(_clname);
}

int DataIndexKeyboardLayout::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KeyboardLayoutBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void DataIndexKeyboardLayout::pathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DataIndexKeyboardLayout::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
