/****************************************************************************
** Meta object code from reading C++ file 'key.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktouch-26.08.0/src/core/key.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'key.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3KeyE_t {};
} // unnamed namespace

template <> constexpr inline auto Key::qt_create_metaobjectdata<qt_meta_tag_ZN3KeyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Key",
        "fingerIndexChanged",
        "",
        "hasHapticMarkerChanged",
        "keyCharCountChanged",
        "keyCharAboutToBeAdded",
        "KeyChar*",
        "keyChar",
        "index",
        "keyCharAdded",
        "keyCharsAboutToBeRemoved",
        "first",
        "last",
        "keyCharsRemoved",
        "keyType",
        "addKeyChar",
        "insertKeyChar",
        "removeKeyChar",
        "clearKeyChars",
        "copyFrom",
        "Key*",
        "source",
        "fingerIndex",
        "hasHapticMarker",
        "keyCharCount"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fingerIndexChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasHapticMarkerChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keyCharCountChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keyCharAboutToBeAdded'
        QtMocHelpers::SignalData<void(KeyChar *, int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::Int, 8 },
        }}),
        // Signal 'keyCharAdded'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keyCharsAboutToBeRemoved'
        QtMocHelpers::SignalData<void(int, int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { QMetaType::Int, 12 },
        }}),
        // Signal 'keyCharsRemoved'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'keyType'
        QtMocHelpers::MethodData<QString() const>(14, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'keyChar'
        QtMocHelpers::MethodData<KeyChar *(int) const>(7, 2, QMC::AccessPublic, 0x80000000 | 6, {{
            { QMetaType::Int, 8 },
        }}),
        // Method 'addKeyChar'
        QtMocHelpers::MethodData<void(KeyChar *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Method 'insertKeyChar'
        QtMocHelpers::MethodData<void(int, KeyChar *)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 }, { 0x80000000 | 6, 7 },
        }}),
        // Method 'removeKeyChar'
        QtMocHelpers::MethodData<void(int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Method 'clearKeyChars'
        QtMocHelpers::MethodData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'copyFrom'
        QtMocHelpers::MethodData<void(Key *)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'fingerIndex'
        QtMocHelpers::PropertyData<int>(22, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'hasHapticMarker'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'keyCharCount'
        QtMocHelpers::PropertyData<int>(24, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Key, qt_meta_tag_ZN3KeyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Key::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractKey::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3KeyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3KeyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3KeyE_t>.metaTypes,
    nullptr
} };

void Key::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Key *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fingerIndexChanged(); break;
        case 1: _t->hasHapticMarkerChanged(); break;
        case 2: _t->keyCharCountChanged(); break;
        case 3: _t->keyCharAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<KeyChar*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->keyCharAdded(); break;
        case 5: _t->keyCharsAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 6: _t->keyCharsRemoved(); break;
        case 7: { QString _r = _t->keyType();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { KeyChar* _r = _t->keyChar((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KeyChar**>(_a[0]) = std::move(_r); }  break;
        case 9: _t->addKeyChar((*reinterpret_cast<std::add_pointer_t<KeyChar*>>(_a[1]))); break;
        case 10: _t->insertKeyChar((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KeyChar*>>(_a[2]))); break;
        case 11: _t->removeKeyChar((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->clearKeyChars(); break;
        case 13: _t->copyFrom((*reinterpret_cast<std::add_pointer_t<Key*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Key* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Key::*)()>(_a, &Key::fingerIndexChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Key::*)()>(_a, &Key::hasHapticMarkerChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Key::*)()>(_a, &Key::keyCharCountChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Key::*)(KeyChar * , int )>(_a, &Key::keyCharAboutToBeAdded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Key::*)()>(_a, &Key::keyCharAdded, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Key::*)(int , int )>(_a, &Key::keyCharsAboutToBeRemoved, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Key::*)()>(_a, &Key::keyCharsRemoved, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->fingerIndex(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->hasHapticMarker(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->keyCharCount(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFingerIndex(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setHasHapticMarker(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Key::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Key::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3KeyE_t>.strings))
        return static_cast<void*>(this);
    return AbstractKey::qt_metacast(_clname);
}

int Key::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractKey::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void Key::fingerIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Key::hasHapticMarkerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Key::keyCharCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Key::keyCharAboutToBeAdded(KeyChar * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void Key::keyCharAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Key::keyCharsAboutToBeRemoved(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void Key::keyCharsRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
