/********************************************************************************
** Form generated from reading UI file 'colorsconfigwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COLORSCONFIGWIDGET_H
#define UI_COLORSCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_ColorsConfigWidget
{
public:
    QVBoxLayout *verticalLayout_3;
    QGroupBox *fingersGroupBox;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer_6;
    QVBoxLayout *verticalLayout;
    QLabel *leftHandLabel;
    QSpacerItem *verticalSpacer_2;
    QFormLayout *formLayout;
    QLabel *fingerLabel3;
    KColorButton *kcfg_FingerColor3;
    QLabel *fingerLabel2;
    KColorButton *kcfg_FingerColor2;
    QLabel *fingerLabel1;
    KColorButton *kcfg_FingerColor1;
    QLabel *fingerLabel0;
    KColorButton *kcfg_FingerColor0;
    QSpacerItem *horizontalSpacer_4;
    QFrame *frame;
    QSpacerItem *horizontalSpacer_5;
    QVBoxLayout *verticalLayout_2;
    QLabel *rightHandLabel;
    QSpacerItem *verticalSpacer_3;
    QFormLayout *formLayout_2;
    QLabel *fingerLabel4;
    KColorButton *kcfg_FingerColor4;
    QLabel *fingerLabel5;
    KColorButton *kcfg_FingerColor5;
    QLabel *fingerLabel6;
    KColorButton *kcfg_FingerColor6;
    QLabel *fingerLabel7;
    KColorButton *kcfg_FingerColor7;
    QSpacerItem *horizontalSpacer_3;
    QSpacerItem *verticalSpacer;
    QFormLayout *formLayout_3;
    QLabel *opacityLabel;
    QDoubleSpinBox *kcfg_FingerOpacity;

    void setupUi(QWidget *ColorsConfigWidget)
    {
        if (ColorsConfigWidget->objectName().isEmpty())
            ColorsConfigWidget->setObjectName("ColorsConfigWidget");
        ColorsConfigWidget->resize(393, 192);
        verticalLayout_3 = new QVBoxLayout(ColorsConfigWidget);
        verticalLayout_3->setObjectName("verticalLayout_3");
        fingersGroupBox = new QGroupBox(ColorsConfigWidget);
        fingersGroupBox->setObjectName("fingersGroupBox");
        horizontalLayout = new QHBoxLayout(fingersGroupBox);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer_6 = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_6);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        leftHandLabel = new QLabel(fingersGroupBox);
        leftHandLabel->setObjectName("leftHandLabel");
        QFont font;
        font.setBold(true);
        leftHandLabel->setFont(font);
        leftHandLabel->setAlignment(Qt::AlignCenter);

        verticalLayout->addWidget(leftHandLabel);

        verticalSpacer_2 = new QSpacerItem(20, 8, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_2);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        fingerLabel3 = new QLabel(fingersGroupBox);
        fingerLabel3->setObjectName("fingerLabel3");
        fingerLabel3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, fingerLabel3);

        kcfg_FingerColor3 = new KColorButton(fingersGroupBox);
        kcfg_FingerColor3->setObjectName("kcfg_FingerColor3");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_FingerColor3);

        fingerLabel2 = new QLabel(fingersGroupBox);
        fingerLabel2->setObjectName("fingerLabel2");
        fingerLabel2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, fingerLabel2);

        kcfg_FingerColor2 = new KColorButton(fingersGroupBox);
        kcfg_FingerColor2->setObjectName("kcfg_FingerColor2");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_FingerColor2);

        fingerLabel1 = new QLabel(fingersGroupBox);
        fingerLabel1->setObjectName("fingerLabel1");
        fingerLabel1->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, fingerLabel1);

        kcfg_FingerColor1 = new KColorButton(fingersGroupBox);
        kcfg_FingerColor1->setObjectName("kcfg_FingerColor1");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_FingerColor1);

        fingerLabel0 = new QLabel(fingersGroupBox);
        fingerLabel0->setObjectName("fingerLabel0");
        fingerLabel0->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, fingerLabel0);

        kcfg_FingerColor0 = new KColorButton(fingersGroupBox);
        kcfg_FingerColor0->setObjectName("kcfg_FingerColor0");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_FingerColor0);


        verticalLayout->addLayout(formLayout);


        horizontalLayout->addLayout(verticalLayout);

        horizontalSpacer_4 = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_4);

        frame = new QFrame(fingersGroupBox);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::VLine);
        frame->setFrameShadow(QFrame::Raised);

        horizontalLayout->addWidget(frame);

        horizontalSpacer_5 = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_5);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        rightHandLabel = new QLabel(fingersGroupBox);
        rightHandLabel->setObjectName("rightHandLabel");
        rightHandLabel->setFont(font);
        rightHandLabel->setAlignment(Qt::AlignCenter);

        verticalLayout_2->addWidget(rightHandLabel);

        verticalSpacer_3 = new QSpacerItem(20, 8, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_2->addItem(verticalSpacer_3);

        formLayout_2 = new QFormLayout();
        formLayout_2->setObjectName("formLayout_2");
        fingerLabel4 = new QLabel(fingersGroupBox);
        fingerLabel4->setObjectName("fingerLabel4");
        fingerLabel4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, fingerLabel4);

        kcfg_FingerColor4 = new KColorButton(fingersGroupBox);
        kcfg_FingerColor4->setObjectName("kcfg_FingerColor4");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_FingerColor4);

        fingerLabel5 = new QLabel(fingersGroupBox);
        fingerLabel5->setObjectName("fingerLabel5");
        fingerLabel5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, fingerLabel5);

        kcfg_FingerColor5 = new KColorButton(fingersGroupBox);
        kcfg_FingerColor5->setObjectName("kcfg_FingerColor5");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_FingerColor5);

        fingerLabel6 = new QLabel(fingersGroupBox);
        fingerLabel6->setObjectName("fingerLabel6");
        fingerLabel6->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, fingerLabel6);

        kcfg_FingerColor6 = new KColorButton(fingersGroupBox);
        kcfg_FingerColor6->setObjectName("kcfg_FingerColor6");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_FingerColor6);

        fingerLabel7 = new QLabel(fingersGroupBox);
        fingerLabel7->setObjectName("fingerLabel7");
        fingerLabel7->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, fingerLabel7);

        kcfg_FingerColor7 = new KColorButton(fingersGroupBox);
        kcfg_FingerColor7->setObjectName("kcfg_FingerColor7");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_FingerColor7);


        verticalLayout_2->addLayout(formLayout_2);


        horizontalLayout->addLayout(verticalLayout_2);

        horizontalSpacer_3 = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_3);


        verticalLayout_3->addWidget(fingersGroupBox);

        verticalSpacer = new QSpacerItem(20, 44, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        formLayout_3 = new QFormLayout();
        formLayout_3->setObjectName("formLayout_3");
        opacityLabel = new QLabel(ColorsConfigWidget);
        opacityLabel->setObjectName("opacityLabel");
        opacityLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, opacityLabel);

        kcfg_FingerOpacity = new QDoubleSpinBox(ColorsConfigWidget);
        kcfg_FingerOpacity->setObjectName("kcfg_FingerOpacity");
        kcfg_FingerOpacity->setDecimals(1);
        kcfg_FingerOpacity->setMinimum(0.000000000000000);
        kcfg_FingerOpacity->setMaximum(100.000000000000000);
        kcfg_FingerOpacity->setSingleStep(0.100000000000000);

        formLayout_3->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_FingerOpacity);


        verticalLayout_3->addLayout(formLayout_3);

#if QT_CONFIG(shortcut)
        fingerLabel3->setBuddy(kcfg_FingerColor3);
        fingerLabel2->setBuddy(kcfg_FingerColor2);
        fingerLabel1->setBuddy(kcfg_FingerColor1);
        fingerLabel0->setBuddy(kcfg_FingerColor0);
        fingerLabel4->setBuddy(kcfg_FingerColor4);
        fingerLabel5->setBuddy(kcfg_FingerColor5);
        fingerLabel6->setBuddy(kcfg_FingerColor6);
        fingerLabel7->setBuddy(kcfg_FingerColor7);
        opacityLabel->setBuddy(kcfg_FingerOpacity);
#endif // QT_CONFIG(shortcut)

        retranslateUi(ColorsConfigWidget);

        QMetaObject::connectSlotsByName(ColorsConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *ColorsConfigWidget)
    {
        fingersGroupBox->setTitle(tr2i18n("Fingers", nullptr));
        leftHandLabel->setText(tr2i18n("Left Hand", nullptr));
        fingerLabel3->setText(tr2i18n("Index finger:", nullptr));
        fingerLabel2->setText(tr2i18n("Middle finger:", nullptr));
        fingerLabel1->setText(tr2i18n("Ring finger:", nullptr));
        fingerLabel0->setText(tr2i18n("Little finger:", nullptr));
        rightHandLabel->setText(tr2i18n("Right Hand", nullptr));
        fingerLabel4->setText(tr2i18n("Index finger:", nullptr));
        fingerLabel5->setText(tr2i18n("Middle finger:", nullptr));
        fingerLabel6->setText(tr2i18n("Ring finger:", nullptr));
        fingerLabel7->setText(tr2i18n("Little finger:", nullptr));
        opacityLabel->setText(tr2i18n("Opacity", nullptr));
        kcfg_FingerOpacity->setSuffix(tr2i18n(" %", nullptr));
        (void)ColorsConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class ColorsConfigWidget: public Ui_ColorsConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // COLORSCONFIGWIDGET_H

