/********************************************************************************
** Form generated from reading UI file 'resourceeditorwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RESOURCEEDITORWIDGET_H
#define UI_RESOURCEEDITORWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include <kmessagewidget.h>
#include "editor/courseeditor.h"
#include "editor/keyboardlayouteditor.h"
#include "kcategorizedview.h"

QT_BEGIN_NAMESPACE

class Ui_ResourceEditorWidget
{
public:
    QVBoxLayout *verticalLayout;
    KMessageWidget *m_messageWidget;
    QSplitter *m_splitter;
    KCategorizedView *m_resourceView;
    QStackedWidget *m_editorStack;
    CourseEditor *m_courseEditor;
    KeyboardLayoutEditor *m_keyboardLayoutEditor;

    void setupUi(QWidget *ResourceEditorWidget)
    {
        if (ResourceEditorWidget->objectName().isEmpty())
            ResourceEditorWidget->setObjectName("ResourceEditorWidget");
        ResourceEditorWidget->resize(558, 483);
        verticalLayout = new QVBoxLayout(ResourceEditorWidget);
        verticalLayout->setObjectName("verticalLayout");
        m_messageWidget = new KMessageWidget(ResourceEditorWidget);
        m_messageWidget->setObjectName("m_messageWidget");

        verticalLayout->addWidget(m_messageWidget);

        m_splitter = new QSplitter(ResourceEditorWidget);
        m_splitter->setObjectName("m_splitter");
        m_splitter->setOrientation(Qt::Horizontal);
        m_splitter->setChildrenCollapsible(false);
        m_resourceView = new KCategorizedView(m_splitter);
        m_resourceView->setObjectName("m_resourceView");
        m_splitter->addWidget(m_resourceView);
        m_editorStack = new QStackedWidget(m_splitter);
        m_editorStack->setObjectName("m_editorStack");
        m_courseEditor = new CourseEditor();
        m_courseEditor->setObjectName("m_courseEditor");
        m_editorStack->addWidget(m_courseEditor);
        m_keyboardLayoutEditor = new KeyboardLayoutEditor();
        m_keyboardLayoutEditor->setObjectName("m_keyboardLayoutEditor");
        m_editorStack->addWidget(m_keyboardLayoutEditor);
        m_splitter->addWidget(m_editorStack);

        verticalLayout->addWidget(m_splitter);


        retranslateUi(ResourceEditorWidget);

        m_editorStack->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ResourceEditorWidget);
    } // setupUi

    void retranslateUi(QWidget *ResourceEditorWidget)
    {
        (void)ResourceEditorWidget;
    } // retranslateUi

};

namespace Ui {
    class ResourceEditorWidget: public Ui_ResourceEditorWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // RESOURCEEDITORWIDGET_H

