/********************************************************************************
** Form generated from reading UI file 'resourcetypeswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RESOURCETYPESWIDGET_H
#define UI_RESOURCETYPESWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QListView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ResourceTypesWidget
{
public:
    QVBoxLayout *vboxLayout;
    QListView *m_typesView;

    void setupUi(QWidget *ResourceTypesWidget)
    {
        if (ResourceTypesWidget->objectName().isEmpty())
            ResourceTypesWidget->setObjectName("ResourceTypesWidget");
        ResourceTypesWidget->resize(542, 386);
        vboxLayout = new QVBoxLayout(ResourceTypesWidget);
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        vboxLayout->setObjectName("vboxLayout");
        m_typesView = new QListView(ResourceTypesWidget);
        m_typesView->setObjectName("m_typesView");

        vboxLayout->addWidget(m_typesView);


        retranslateUi(ResourceTypesWidget);

        QMetaObject::connectSlotsByName(ResourceTypesWidget);
    } // setupUi

    void retranslateUi(QWidget *ResourceTypesWidget)
    {
        (void)ResourceTypesWidget;
    } // retranslateUi

};

namespace Ui {
    class ResourceTypesWidget: public Ui_ResourceTypesWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // RESOURCETYPESWIDGET_H

