/****************************************************************************
** Meta object code from reading C++ file 'courseeditor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktouch-26.08.0/src/editor/courseeditor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'courseeditor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12CourseEditorE_t {};
} // unnamed namespace

template <> constexpr inline auto CourseEditor::qt_create_metaobjectdata<qt_meta_tag_ZN12CourseEditorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CourseEditor",
        "setTitle",
        "",
        "newTitle",
        "setKeyboardLayoutName",
        "newName",
        "setDescription",
        "newDescription",
        "addLesson",
        "removeLesson",
        "moveLessonUp",
        "moveLessonDown",
        "setLessonTitle",
        "setLessonNewCharacters",
        "newCharacters",
        "setLessonText",
        "text",
        "updateTitle",
        "updateKeyboardLayoutName",
        "updateDescription",
        "updateLessonTitle",
        "updateLessonNewCharacters",
        "updateLessonText",
        "updateLessonCharacters",
        "onKeyboardLayoutChosen",
        "onDescriptionChanged",
        "onLessonTextChanged",
        "selectLesson",
        "index",
        "onLessonSelected"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'setTitle'
        QtMocHelpers::SlotData<void(const QString &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'setKeyboardLayoutName'
        QtMocHelpers::SlotData<void(const QString &)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'setDescription'
        QtMocHelpers::SlotData<void(const QString &)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'addLesson'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removeLesson'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'moveLessonUp'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'moveLessonDown'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setLessonTitle'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'setLessonNewCharacters'
        QtMocHelpers::SlotData<void(const QString &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'setLessonText'
        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'updateTitle'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateKeyboardLayoutName'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateDescription'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateLessonTitle'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateLessonNewCharacters'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateLessonText'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateLessonCharacters'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onKeyboardLayoutChosen'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDescriptionChanged'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onLessonTextChanged'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'selectLesson'
        QtMocHelpers::SlotData<void(int)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 28 },
        }}),
        // Slot 'onLessonSelected'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CourseEditor, qt_meta_tag_ZN12CourseEditorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CourseEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractEditor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12CourseEditorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12CourseEditorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12CourseEditorE_t>.metaTypes,
    nullptr
} };

void CourseEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CourseEditor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->setKeyboardLayoutName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->setDescription((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->addLesson(); break;
        case 4: _t->removeLesson(); break;
        case 5: _t->moveLessonUp(); break;
        case 6: _t->moveLessonDown(); break;
        case 7: _t->setLessonTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->setLessonNewCharacters((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->setLessonText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->updateTitle(); break;
        case 11: _t->updateKeyboardLayoutName(); break;
        case 12: _t->updateDescription(); break;
        case 13: _t->updateLessonTitle(); break;
        case 14: _t->updateLessonNewCharacters(); break;
        case 15: _t->updateLessonText(); break;
        case 16: _t->updateLessonCharacters(); break;
        case 17: _t->onKeyboardLayoutChosen(); break;
        case 18: _t->onDescriptionChanged(); break;
        case 19: _t->onLessonTextChanged(); break;
        case 20: _t->selectLesson((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->onLessonSelected(); break;
        default: ;
        }
    }
}

const QMetaObject *CourseEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CourseEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12CourseEditorE_t>.strings))
        return static_cast<void*>(this);
    return AbstractEditor::qt_metacast(_clname);
}

int CourseEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractEditor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 22;
    }
    return _id;
}
QT_WARNING_POP
