/********************************************************************************
** Form generated from reading UI file 'courseeditor.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COURSEEDITOR_H
#define UI_COURSEEDITOR_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListView>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include <kmessagewidget.h>
#include "editor/keyboardlayoutcombobox.h"
#include "editor/lessontexteditor.h"
#include "klineedit.h"
#include "ktextedit.h"

QT_BEGIN_NAMESPACE

class Ui_CourseEditor
{
public:
    QVBoxLayout *verticalLayout_2;
    KMessageWidget *m_messageWidget;
    QFormLayout *m_formLayout;
    QLabel *m_titleLabel;
    KLineEdit *m_titleLineEdit;
    QLabel *m_keyboardLayoutLabel;
    KeyboardLayoutComboBox *m_keyboardLayoutComboBox;
    QLabel *m_descriptionLabel;
    KTextEdit *m_descriptionTextEdit;
    QSpacerItem *m_verticalSpacer_4;
    QGroupBox *m_lessonGroupBox;
    QHBoxLayout *horizontalLayout_2;
    QSplitter *m_lessonsSplitter;
    QWidget *layoutWidget;
    QVBoxLayout *m_verticalLayout;
    QHBoxLayout *m_horizontalLayout;
    QLabel *m_lessonsLabel;
    QSpacerItem *m_horizontalSpacer;
    QToolButton *m_addLessonButton;
    QToolButton *m_removeLessonButton;
    QSpacerItem *m_horizontalSpacer_2;
    QToolButton *m_moveLessonUpButton;
    QToolButton *m_moveLessonDownButton;
    QListView *m_lessonView;
    QWidget *layoutWidget_2;
    QHBoxLayout *m_horizontalLayout_3;
    QSpacerItem *m_horizontalSpacer_5;
    QVBoxLayout *m_verticalLayout_3;
    QFormLayout *m_formLayout_2;
    QLabel *m_lessonTitleLabel;
    KLineEdit *m_lessonTitleLineEdit;
    QLabel *m_newCharactersLabel;
    KLineEdit *m_newCharactersLineEdit;
    QSpacerItem *m_verticalSpacer;
    LessonTextEditor *m_lessonTextEditor;

    void setupUi(QWidget *CourseEditor)
    {
        if (CourseEditor->objectName().isEmpty())
            CourseEditor->setObjectName("CourseEditor");
        CourseEditor->resize(599, 491);
        verticalLayout_2 = new QVBoxLayout(CourseEditor);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(-1, 0, 0, 0);
        m_messageWidget = new KMessageWidget(CourseEditor);
        m_messageWidget->setObjectName("m_messageWidget");

        verticalLayout_2->addWidget(m_messageWidget);

        m_formLayout = new QFormLayout();
        m_formLayout->setObjectName("m_formLayout");
        m_formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        m_formLayout->setHorizontalSpacing(4);
        m_formLayout->setVerticalSpacing(4);
        m_titleLabel = new QLabel(CourseEditor);
        m_titleLabel->setObjectName("m_titleLabel");

        m_formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, m_titleLabel);

        m_titleLineEdit = new KLineEdit(CourseEditor);
        m_titleLineEdit->setObjectName("m_titleLineEdit");

        m_formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, m_titleLineEdit);

        m_keyboardLayoutLabel = new QLabel(CourseEditor);
        m_keyboardLayoutLabel->setObjectName("m_keyboardLayoutLabel");

        m_formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, m_keyboardLayoutLabel);

        m_keyboardLayoutComboBox = new KeyboardLayoutComboBox(CourseEditor);
        m_keyboardLayoutComboBox->setObjectName("m_keyboardLayoutComboBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_keyboardLayoutComboBox->sizePolicy().hasHeightForWidth());
        m_keyboardLayoutComboBox->setSizePolicy(sizePolicy);

        m_formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, m_keyboardLayoutComboBox);

        m_descriptionLabel = new QLabel(CourseEditor);
        m_descriptionLabel->setObjectName("m_descriptionLabel");

        m_formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, m_descriptionLabel);

        m_descriptionTextEdit = new KTextEdit(CourseEditor);
        m_descriptionTextEdit->setObjectName("m_descriptionTextEdit");
        sizePolicy.setHeightForWidth(m_descriptionTextEdit->sizePolicy().hasHeightForWidth());
        m_descriptionTextEdit->setSizePolicy(sizePolicy);
        m_descriptionTextEdit->setMaximumSize(QSize(16777215, 76));
        m_descriptionTextEdit->setTabChangesFocus(true);
        m_descriptionTextEdit->setAcceptRichText(false);

        m_formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, m_descriptionTextEdit);


        verticalLayout_2->addLayout(m_formLayout);

        m_verticalSpacer_4 = new QSpacerItem(20, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_2->addItem(m_verticalSpacer_4);

        m_lessonGroupBox = new QGroupBox(CourseEditor);
        m_lessonGroupBox->setObjectName("m_lessonGroupBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_lessonGroupBox->sizePolicy().hasHeightForWidth());
        m_lessonGroupBox->setSizePolicy(sizePolicy1);
        horizontalLayout_2 = new QHBoxLayout(m_lessonGroupBox);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(-1, -1, -1, 0);
        m_lessonsSplitter = new QSplitter(m_lessonGroupBox);
        m_lessonsSplitter->setObjectName("m_lessonsSplitter");
        m_lessonsSplitter->setOrientation(Qt::Horizontal);
        m_lessonsSplitter->setChildrenCollapsible(false);
        layoutWidget = new QWidget(m_lessonsSplitter);
        layoutWidget->setObjectName("layoutWidget");
        m_verticalLayout = new QVBoxLayout(layoutWidget);
        m_verticalLayout->setSpacing(0);
        m_verticalLayout->setObjectName("m_verticalLayout");
        m_verticalLayout->setContentsMargins(0, 0, 0, 0);
        m_horizontalLayout = new QHBoxLayout();
        m_horizontalLayout->setSpacing(0);
        m_horizontalLayout->setObjectName("m_horizontalLayout");
        m_lessonsLabel = new QLabel(layoutWidget);
        m_lessonsLabel->setObjectName("m_lessonsLabel");

        m_horizontalLayout->addWidget(m_lessonsLabel);

        m_horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);

        m_horizontalLayout->addItem(m_horizontalSpacer);

        m_addLessonButton = new QToolButton(layoutWidget);
        m_addLessonButton->setObjectName("m_addLessonButton");
        m_addLessonButton->setEnabled(false);
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        m_addLessonButton->setIcon(icon);

        m_horizontalLayout->addWidget(m_addLessonButton);

        m_removeLessonButton = new QToolButton(layoutWidget);
        m_removeLessonButton->setObjectName("m_removeLessonButton");
        m_removeLessonButton->setEnabled(false);
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("list-remove")));
        m_removeLessonButton->setIcon(icon1);

        m_horizontalLayout->addWidget(m_removeLessonButton);

        m_horizontalSpacer_2 = new QSpacerItem(10, 10, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        m_horizontalLayout->addItem(m_horizontalSpacer_2);

        m_moveLessonUpButton = new QToolButton(layoutWidget);
        m_moveLessonUpButton->setObjectName("m_moveLessonUpButton");
        m_moveLessonUpButton->setEnabled(false);
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("arrow-up")));
        m_moveLessonUpButton->setIcon(icon2);

        m_horizontalLayout->addWidget(m_moveLessonUpButton);

        m_moveLessonDownButton = new QToolButton(layoutWidget);
        m_moveLessonDownButton->setObjectName("m_moveLessonDownButton");
        m_moveLessonDownButton->setEnabled(false);
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("arrow-down")));
        m_moveLessonDownButton->setIcon(icon3);

        m_horizontalLayout->addWidget(m_moveLessonDownButton);


        m_verticalLayout->addLayout(m_horizontalLayout);

        m_lessonView = new QListView(layoutWidget);
        m_lessonView->setObjectName("m_lessonView");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(m_lessonView->sizePolicy().hasHeightForWidth());
        m_lessonView->setSizePolicy(sizePolicy2);

        m_verticalLayout->addWidget(m_lessonView);

        m_lessonsSplitter->addWidget(layoutWidget);
        layoutWidget_2 = new QWidget(m_lessonsSplitter);
        layoutWidget_2->setObjectName("layoutWidget_2");
        m_horizontalLayout_3 = new QHBoxLayout(layoutWidget_2);
        m_horizontalLayout_3->setObjectName("m_horizontalLayout_3");
        m_horizontalLayout_3->setContentsMargins(0, 0, 0, 0);
        m_horizontalSpacer_5 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        m_horizontalLayout_3->addItem(m_horizontalSpacer_5);

        m_verticalLayout_3 = new QVBoxLayout();
        m_verticalLayout_3->setSpacing(0);
        m_verticalLayout_3->setObjectName("m_verticalLayout_3");
        m_formLayout_2 = new QFormLayout();
        m_formLayout_2->setObjectName("m_formLayout_2");
        m_formLayout_2->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        m_formLayout_2->setHorizontalSpacing(4);
        m_formLayout_2->setVerticalSpacing(4);
        m_lessonTitleLabel = new QLabel(layoutWidget_2);
        m_lessonTitleLabel->setObjectName("m_lessonTitleLabel");

        m_formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, m_lessonTitleLabel);

        m_lessonTitleLineEdit = new KLineEdit(layoutWidget_2);
        m_lessonTitleLineEdit->setObjectName("m_lessonTitleLineEdit");
        m_lessonTitleLineEdit->setEnabled(false);

        m_formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, m_lessonTitleLineEdit);

        m_newCharactersLabel = new QLabel(layoutWidget_2);
        m_newCharactersLabel->setObjectName("m_newCharactersLabel");

        m_formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, m_newCharactersLabel);

        m_newCharactersLineEdit = new KLineEdit(layoutWidget_2);
        m_newCharactersLineEdit->setObjectName("m_newCharactersLineEdit");
        m_newCharactersLineEdit->setEnabled(false);

        m_formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, m_newCharactersLineEdit);


        m_verticalLayout_3->addLayout(m_formLayout_2);

        m_verticalSpacer = new QSpacerItem(20, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        m_verticalLayout_3->addItem(m_verticalSpacer);

        m_lessonTextEditor = new LessonTextEditor(layoutWidget_2);
        m_lessonTextEditor->setObjectName("m_lessonTextEditor");

        m_verticalLayout_3->addWidget(m_lessonTextEditor);


        m_horizontalLayout_3->addLayout(m_verticalLayout_3);

        m_lessonsSplitter->addWidget(layoutWidget_2);

        horizontalLayout_2->addWidget(m_lessonsSplitter);


        verticalLayout_2->addWidget(m_lessonGroupBox);

#if QT_CONFIG(shortcut)
        m_titleLabel->setBuddy(m_titleLineEdit);
        m_keyboardLayoutLabel->setBuddy(m_keyboardLayoutComboBox);
        m_descriptionLabel->setBuddy(m_descriptionTextEdit);
        m_lessonsLabel->setBuddy(m_lessonView);
        m_lessonTitleLabel->setBuddy(m_lessonTitleLineEdit);
        m_newCharactersLabel->setBuddy(m_newCharactersLineEdit);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(m_titleLineEdit, m_keyboardLayoutComboBox);
        QWidget::setTabOrder(m_keyboardLayoutComboBox, m_descriptionTextEdit);
        QWidget::setTabOrder(m_descriptionTextEdit, m_lessonView);
        QWidget::setTabOrder(m_lessonView, m_addLessonButton);
        QWidget::setTabOrder(m_addLessonButton, m_removeLessonButton);
        QWidget::setTabOrder(m_removeLessonButton, m_moveLessonUpButton);
        QWidget::setTabOrder(m_moveLessonUpButton, m_moveLessonDownButton);
        QWidget::setTabOrder(m_moveLessonDownButton, m_lessonTitleLineEdit);
        QWidget::setTabOrder(m_lessonTitleLineEdit, m_newCharactersLineEdit);

        retranslateUi(CourseEditor);

        QMetaObject::connectSlotsByName(CourseEditor);
    } // setupUi

    void retranslateUi(QWidget *CourseEditor)
    {
        m_titleLabel->setText(tr2i18n("Title:", nullptr));
        m_keyboardLayoutLabel->setText(tr2i18n("Keyboard layout:", nullptr));
        m_descriptionLabel->setText(tr2i18n("Description:", nullptr));
        m_lessonsLabel->setText(tr2i18n("Lessons:", nullptr));
#if QT_CONFIG(tooltip)
        m_addLessonButton->setToolTip(tr2i18n("Add new lesson", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        m_removeLessonButton->setToolTip(tr2i18n("Remove lesson", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        m_moveLessonUpButton->setToolTip(tr2i18n("Move lesson up", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        m_moveLessonDownButton->setToolTip(tr2i18n("Move lesson down", nullptr));
#endif // QT_CONFIG(tooltip)
        m_lessonTitleLabel->setText(tr2i18n("Title:", nullptr));
        m_newCharactersLabel->setText(tr2i18n("New characters:", nullptr));
        (void)CourseEditor;
    } // retranslateUi

};

namespace Ui {
    class CourseEditor: public Ui_CourseEditor {};
} // namespace Ui

QT_END_NAMESPACE

#endif // COURSEEDITOR_H

