/********************************************************************************
** Form generated from reading UI file 'newcoursewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NEWCOURSEWIDGET_H
#define UI_NEWCOURSEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "editor/keyboardlayoutcombobox.h"
#include "klineedit.h"
#include "ktextedit.h"

QT_BEGIN_NAMESPACE

class Ui_NewCourseWidget
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *m_formLayout;
    QLabel *m_titleLabel;
    KLineEdit *m_titleLineEdit;
    QLabel *m_keyboardLayoutLabel;
    KeyboardLayoutComboBox *m_keyboardLayoutComboBox;
    QLabel *m_descriptionLabel;
    KTextEdit *m_descriptionEdit;

    void setupUi(QWidget *NewCourseWidget)
    {
        if (NewCourseWidget->objectName().isEmpty())
            NewCourseWidget->setObjectName("NewCourseWidget");
        NewCourseWidget->resize(336, 133);
        verticalLayout = new QVBoxLayout(NewCourseWidget);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName("verticalLayout");
        m_formLayout = new QFormLayout();
        m_formLayout->setObjectName("m_formLayout");
        m_formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        m_titleLabel = new QLabel(NewCourseWidget);
        m_titleLabel->setObjectName("m_titleLabel");

        m_formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, m_titleLabel);

        m_titleLineEdit = new KLineEdit(NewCourseWidget);
        m_titleLineEdit->setObjectName("m_titleLineEdit");

        m_formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, m_titleLineEdit);

        m_keyboardLayoutLabel = new QLabel(NewCourseWidget);
        m_keyboardLayoutLabel->setObjectName("m_keyboardLayoutLabel");

        m_formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, m_keyboardLayoutLabel);

        m_keyboardLayoutComboBox = new KeyboardLayoutComboBox(NewCourseWidget);
        m_keyboardLayoutComboBox->setObjectName("m_keyboardLayoutComboBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_keyboardLayoutComboBox->sizePolicy().hasHeightForWidth());
        m_keyboardLayoutComboBox->setSizePolicy(sizePolicy);

        m_formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, m_keyboardLayoutComboBox);

        m_descriptionLabel = new QLabel(NewCourseWidget);
        m_descriptionLabel->setObjectName("m_descriptionLabel");

        m_formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, m_descriptionLabel);

        m_descriptionEdit = new KTextEdit(NewCourseWidget);
        m_descriptionEdit->setObjectName("m_descriptionEdit");
        m_descriptionEdit->setTabChangesFocus(true);
        m_descriptionEdit->setAcceptRichText(false);

        m_formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, m_descriptionEdit);


        verticalLayout->addLayout(m_formLayout);

#if QT_CONFIG(shortcut)
        m_titleLabel->setBuddy(m_titleLineEdit);
        m_keyboardLayoutLabel->setBuddy(m_keyboardLayoutComboBox);
        m_descriptionLabel->setBuddy(m_descriptionEdit);
#endif // QT_CONFIG(shortcut)

        retranslateUi(NewCourseWidget);

        QMetaObject::connectSlotsByName(NewCourseWidget);
    } // setupUi

    void retranslateUi(QWidget *NewCourseWidget)
    {
        m_titleLabel->setText(tr2i18n("Title:", nullptr));
        m_keyboardLayoutLabel->setText(tr2i18n("Keyboard layout:", nullptr));
        m_descriptionLabel->setText(tr2i18n("Description:", nullptr));
        (void)NewCourseWidget;
    } // retranslateUi

};

namespace Ui {
    class NewCourseWidget: public Ui_NewCourseWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NEWCOURSEWIDGET_H

