/****************************************************************************
** Meta object code from reading C++ file 'kcolorschemeproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktouch-26.08.0/src/declarativeitems/kcolorschemeproxy.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcolorschemeproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17KColorSchemeProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto KColorSchemeProxy::qt_create_metaobjectdata<qt_meta_tag_ZN17KColorSchemeProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KColorSchemeProxy",
        "colorGroupChanged",
        "",
        "colorSetChanged",
        "paletteChanged",
        "shade",
        "QColor",
        "color",
        "ShadeRole",
        "role",
        "contrast",
        "chromaAdjust",
        "colorGroup",
        "ColorGroup",
        "colorSet",
        "ColorSet",
        "normalBackground",
        "alternateBackground",
        "activeBackground",
        "linkBackground",
        "visitedBackground",
        "negativeBackground",
        "neutralBackground",
        "positiveBackground",
        "focusDecoration",
        "hoverDecoration",
        "normalText",
        "activeText",
        "linkText",
        "visitedText",
        "negativeText",
        "neutralText",
        "positiveText",
        "lightShade",
        "midlightShade",
        "midShade",
        "darkShade",
        "shadowShade",
        "Active",
        "Disabled",
        "Inactive",
        "NColorGroups",
        "Current",
        "All",
        "Normal",
        "View",
        "Window",
        "Button",
        "Selection",
        "Tooltip",
        "Complementary",
        "LightShade",
        "MidlightShade",
        "MidShade",
        "DarkShade",
        "ShadowShade"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'colorGroupChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorSetChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paletteChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'shade'
        QtMocHelpers::MethodData<QColor(const QColor &, enum ShadeRole) const>(5, 2, QMC::AccessPublic, 0x80000000 | 6, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Method 'shade'
        QtMocHelpers::MethodData<QColor(const QColor &, enum ShadeRole, qreal, qreal) const>(5, 2, QMC::AccessPublic, 0x80000000 | 6, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 }, { QMetaType::QReal, 10 }, { QMetaType::QReal, 11 },
        }}),
        // Method 'shade'
        QtMocHelpers::MethodData<QColor(const QColor &, enum ShadeRole, qreal) const>(5, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 6, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 }, { QMetaType::QReal, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'colorGroup'
        QtMocHelpers::PropertyData<enum ColorGroup>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'colorSet'
        QtMocHelpers::PropertyData<enum ColorSet>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'normalBackground'
        QtMocHelpers::PropertyData<QColor>(16, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'alternateBackground'
        QtMocHelpers::PropertyData<QColor>(17, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'activeBackground'
        QtMocHelpers::PropertyData<QColor>(18, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'linkBackground'
        QtMocHelpers::PropertyData<QColor>(19, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'visitedBackground'
        QtMocHelpers::PropertyData<QColor>(20, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'negativeBackground'
        QtMocHelpers::PropertyData<QColor>(21, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'neutralBackground'
        QtMocHelpers::PropertyData<QColor>(22, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'positiveBackground'
        QtMocHelpers::PropertyData<QColor>(23, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'focusDecoration'
        QtMocHelpers::PropertyData<QColor>(24, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'hoverDecoration'
        QtMocHelpers::PropertyData<QColor>(25, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'normalText'
        QtMocHelpers::PropertyData<QColor>(26, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'activeText'
        QtMocHelpers::PropertyData<QColor>(27, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'linkText'
        QtMocHelpers::PropertyData<QColor>(28, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'visitedText'
        QtMocHelpers::PropertyData<QColor>(29, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'negativeText'
        QtMocHelpers::PropertyData<QColor>(30, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'neutralText'
        QtMocHelpers::PropertyData<QColor>(31, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'positiveText'
        QtMocHelpers::PropertyData<QColor>(32, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'lightShade'
        QtMocHelpers::PropertyData<QColor>(33, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'midlightShade'
        QtMocHelpers::PropertyData<QColor>(34, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'midShade'
        QtMocHelpers::PropertyData<QColor>(35, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'darkShade'
        QtMocHelpers::PropertyData<QColor>(36, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'shadowShade'
        QtMocHelpers::PropertyData<QColor>(37, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'contrast'
        QtMocHelpers::PropertyData<qreal>(10, QMetaType::QReal, QMC::DefaultPropertyFlags, 2),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ColorGroup'
        QtMocHelpers::EnumData<enum ColorGroup>(13, 13, QMC::EnumFlags{}).add({
            {   38, ColorGroup::Active },
            {   39, ColorGroup::Disabled },
            {   40, ColorGroup::Inactive },
            {   41, ColorGroup::NColorGroups },
            {   42, ColorGroup::Current },
            {   43, ColorGroup::All },
            {   44, ColorGroup::Normal },
        }),
        // enum 'ColorSet'
        QtMocHelpers::EnumData<enum ColorSet>(15, 15, QMC::EnumFlags{}).add({
            {   45, ColorSet::View },
            {   46, ColorSet::Window },
            {   47, ColorSet::Button },
            {   48, ColorSet::Selection },
            {   49, ColorSet::Tooltip },
            {   50, ColorSet::Complementary },
        }),
        // enum 'ShadeRole'
        QtMocHelpers::EnumData<enum ShadeRole>(8, 8, QMC::EnumFlags{}).add({
            {   51, ShadeRole::LightShade },
            {   52, ShadeRole::MidlightShade },
            {   53, ShadeRole::MidShade },
            {   54, ShadeRole::DarkShade },
            {   55, ShadeRole::ShadowShade },
        }),
    };
    return QtMocHelpers::metaObjectData<KColorSchemeProxy, qt_meta_tag_ZN17KColorSchemeProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KColorSchemeProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KColorSchemeProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KColorSchemeProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17KColorSchemeProxyE_t>.metaTypes,
    nullptr
} };

void KColorSchemeProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KColorSchemeProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->colorGroupChanged(); break;
        case 1: _t->colorSetChanged(); break;
        case 2: _t->paletteChanged(); break;
        case 3: { QColor _r = _t->shade((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum ShadeRole>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 4: { QColor _r = _t->shade((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum ShadeRole>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 5: { QColor _r = _t->shade((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum ShadeRole>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KColorSchemeProxy::*)()>(_a, &KColorSchemeProxy::colorGroupChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KColorSchemeProxy::*)()>(_a, &KColorSchemeProxy::colorSetChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KColorSchemeProxy::*)()>(_a, &KColorSchemeProxy::paletteChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum ColorGroup*>(_v) = _t->colorGroup(); break;
        case 1: *reinterpret_cast<enum ColorSet*>(_v) = _t->colorSet(); break;
        case 2: *reinterpret_cast<QColor*>(_v) = _t->normalBackground(); break;
        case 3: *reinterpret_cast<QColor*>(_v) = _t->alternateBackground(); break;
        case 4: *reinterpret_cast<QColor*>(_v) = _t->activeBackground(); break;
        case 5: *reinterpret_cast<QColor*>(_v) = _t->linkBackground(); break;
        case 6: *reinterpret_cast<QColor*>(_v) = _t->visitedBackground(); break;
        case 7: *reinterpret_cast<QColor*>(_v) = _t->negativeBackground(); break;
        case 8: *reinterpret_cast<QColor*>(_v) = _t->neutralBackground(); break;
        case 9: *reinterpret_cast<QColor*>(_v) = _t->positiveBackground(); break;
        case 10: *reinterpret_cast<QColor*>(_v) = _t->focusDecoration(); break;
        case 11: *reinterpret_cast<QColor*>(_v) = _t->hoverDecoration(); break;
        case 12: *reinterpret_cast<QColor*>(_v) = _t->normalText(); break;
        case 13: *reinterpret_cast<QColor*>(_v) = _t->activeText(); break;
        case 14: *reinterpret_cast<QColor*>(_v) = _t->linkText(); break;
        case 15: *reinterpret_cast<QColor*>(_v) = _t->visitedText(); break;
        case 16: *reinterpret_cast<QColor*>(_v) = _t->negativeText(); break;
        case 17: *reinterpret_cast<QColor*>(_v) = _t->neutralText(); break;
        case 18: *reinterpret_cast<QColor*>(_v) = _t->positiveText(); break;
        case 19: *reinterpret_cast<QColor*>(_v) = _t->lightShade(); break;
        case 20: *reinterpret_cast<QColor*>(_v) = _t->midlightShade(); break;
        case 21: *reinterpret_cast<QColor*>(_v) = _t->midShade(); break;
        case 22: *reinterpret_cast<QColor*>(_v) = _t->darkShade(); break;
        case 23: *reinterpret_cast<QColor*>(_v) = _t->shadowShade(); break;
        case 24: *reinterpret_cast<qreal*>(_v) = _t->contrast(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setColorGroup(*reinterpret_cast<enum ColorGroup*>(_v)); break;
        case 1: _t->setColorSet(*reinterpret_cast<enum ColorSet*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KColorSchemeProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KColorSchemeProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KColorSchemeProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KColorSchemeProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    return _id;
}

// SIGNAL 0
void KColorSchemeProxy::colorGroupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KColorSchemeProxy::colorSetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KColorSchemeProxy::paletteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
