/********************************************************************************
** Form generated from reading UI file 'lessontexteditor.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LESSONTEXTEDITOR_H
#define UI_LESSONTEXTEDITOR_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ktextedit.h"

QT_BEGIN_NAMESPACE

class Ui_LessonTextEditor
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QToolButton *m_openTextFileButton;
    QToolButton *m_reformatLessonTextButton;
    QSpacerItem *horizontalSpacer;
    QLabel *m_characterCountLabel;
    KTextEdit *m_lessonTextEdit;

    void setupUi(QWidget *LessonTextEditor)
    {
        if (LessonTextEditor->objectName().isEmpty())
            LessonTextEditor->setObjectName("LessonTextEditor");
        LessonTextEditor->resize(632, 423);
        verticalLayout = new QVBoxLayout(LessonTextEditor);
        verticalLayout->setSpacing(0);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(0);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(-1, -1, 0, -1);
        m_openTextFileButton = new QToolButton(LessonTextEditor);
        m_openTextFileButton->setObjectName("m_openTextFileButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("document-open")));
        m_openTextFileButton->setIcon(icon);
        m_openTextFileButton->setAutoRaise(true);

        horizontalLayout->addWidget(m_openTextFileButton);

        m_reformatLessonTextButton = new QToolButton(LessonTextEditor);
        m_reformatLessonTextButton->setObjectName("m_reformatLessonTextButton");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("format-justify-fill")));
        m_reformatLessonTextButton->setIcon(icon1);
        m_reformatLessonTextButton->setAutoRaise(true);

        horizontalLayout->addWidget(m_reformatLessonTextButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        m_characterCountLabel = new QLabel(LessonTextEditor);
        m_characterCountLabel->setObjectName("m_characterCountLabel");
        m_characterCountLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout->addWidget(m_characterCountLabel);


        verticalLayout->addLayout(horizontalLayout);

        m_lessonTextEdit = new KTextEdit(LessonTextEditor);
        m_lessonTextEdit->setObjectName("m_lessonTextEdit");
        QFont font;
        font.setFamilies({QString::fromUtf8("Monospace")});
        m_lessonTextEdit->setFont(font);
        m_lessonTextEdit->setLineWrapMode(QTextEdit::NoWrap);
        m_lessonTextEdit->setAcceptRichText(false);

        verticalLayout->addWidget(m_lessonTextEdit);

        QWidget::setTabOrder(m_lessonTextEdit, m_openTextFileButton);
        QWidget::setTabOrder(m_openTextFileButton, m_reformatLessonTextButton);

        retranslateUi(LessonTextEditor);

        QMetaObject::connectSlotsByName(LessonTextEditor);
    } // setupUi

    void retranslateUi(QWidget *LessonTextEditor)
    {
#if QT_CONFIG(tooltip)
        m_openTextFileButton->setToolTip(tr2i18n("Open a text file...", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        m_reformatLessonTextButton->setToolTip(tr2i18n("Wrap lines automatically", nullptr));
#endif // QT_CONFIG(tooltip)
        m_characterCountLabel->setText(tr2i18n("0 Characters", nullptr));
        (void)LessonTextEditor;
    } // retranslateUi

};

namespace Ui {
    class LessonTextEditor: public Ui_LessonTextEditor {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LESSONTEXTEDITOR_H

