/****************************************************************************
** Meta object code from reading C++ file 'course.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktouch-26.08.0/src/core/course.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'course.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6CourseE_t {};
} // unnamed namespace

template <> constexpr inline auto Course::qt_create_metaobjectdata<qt_meta_tag_ZN6CourseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Course",
        "associatedDataIndexCourseChanged",
        "",
        "lessonCountChanged",
        "kindChanged",
        "lessonAboutToBeAdded",
        "Lesson*",
        "lesson",
        "index",
        "lessonAdded",
        "lessonsAboutToBeRemoved",
        "first",
        "last",
        "lessonsRemoved",
        "updateLessonCharacters",
        "firstIndex",
        "addLesson",
        "insertLesson",
        "removeLesson",
        "indexOfLesson",
        "clearLessons",
        "copyFrom",
        "Course*",
        "source",
        "associatedDataIndexCourse",
        "DataIndexCourse*",
        "lessonCount",
        "kind",
        "Kind",
        "SequentialCourse",
        "LessonCollection"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'associatedDataIndexCourseChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lessonCountChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'kindChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lessonAboutToBeAdded'
        QtMocHelpers::SignalData<void(Lesson *, int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::Int, 8 },
        }}),
        // Signal 'lessonAdded'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lessonsAboutToBeRemoved'
        QtMocHelpers::SignalData<void(int, int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { QMetaType::Int, 12 },
        }}),
        // Signal 'lessonsRemoved'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateLessonCharacters'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'updateLessonCharacters'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Method 'lesson'
        QtMocHelpers::MethodData<Lesson *(int) const>(7, 2, QMC::AccessPublic, 0x80000000 | 6, {{
            { QMetaType::Int, 8 },
        }}),
        // Method 'addLesson'
        QtMocHelpers::MethodData<void(Lesson *)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Method 'insertLesson'
        QtMocHelpers::MethodData<void(int, Lesson *)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 }, { 0x80000000 | 6, 7 },
        }}),
        // Method 'removeLesson'
        QtMocHelpers::MethodData<void(int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Method 'indexOfLesson'
        QtMocHelpers::MethodData<int(Lesson *)>(19, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Method 'clearLessons'
        QtMocHelpers::MethodData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'copyFrom'
        QtMocHelpers::MethodData<void(Course *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'associatedDataIndexCourse'
        QtMocHelpers::PropertyData<DataIndexCourse*>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'lessonCount'
        QtMocHelpers::PropertyData<int>(26, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
        // property 'kind'
        QtMocHelpers::PropertyData<enum Kind>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Kind'
        QtMocHelpers::EnumData<enum Kind>(28, 28, QMC::EnumFlags{}).add({
            {   29, Kind::SequentialCourse },
            {   30, Kind::LessonCollection },
        }),
    };
    return QtMocHelpers::metaObjectData<Course, qt_meta_tag_ZN6CourseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Course::staticMetaObject = { {
    QMetaObject::SuperData::link<CourseBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6CourseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6CourseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6CourseE_t>.metaTypes,
    nullptr
} };

void Course::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Course *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->associatedDataIndexCourseChanged(); break;
        case 1: _t->lessonCountChanged(); break;
        case 2: _t->kindChanged(); break;
        case 3: _t->lessonAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<Lesson*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->lessonAdded(); break;
        case 5: _t->lessonsAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 6: _t->lessonsRemoved(); break;
        case 7: _t->updateLessonCharacters((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->updateLessonCharacters(); break;
        case 9: { Lesson* _r = _t->lesson((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Lesson**>(_a[0]) = std::move(_r); }  break;
        case 10: _t->addLesson((*reinterpret_cast<std::add_pointer_t<Lesson*>>(_a[1]))); break;
        case 11: _t->insertLesson((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Lesson*>>(_a[2]))); break;
        case 12: _t->removeLesson((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: { int _r = _t->indexOfLesson((*reinterpret_cast<std::add_pointer_t<Lesson*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->clearLessons(); break;
        case 15: _t->copyFrom((*reinterpret_cast<std::add_pointer_t<Course*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Course* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Course::*)()>(_a, &Course::associatedDataIndexCourseChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Course::*)()>(_a, &Course::lessonCountChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Course::*)()>(_a, &Course::kindChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Course::*)(Lesson * , int )>(_a, &Course::lessonAboutToBeAdded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Course::*)()>(_a, &Course::lessonAdded, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Course::*)(int , int )>(_a, &Course::lessonsAboutToBeRemoved, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Course::*)()>(_a, &Course::lessonsRemoved, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<DataIndexCourse**>(_v) = _t->associatedDataIndexCourse(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->lessonCount(); break;
        case 2: *reinterpret_cast<enum Kind*>(_v) = _t->kind(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAssociatedDataIndexCourse(*reinterpret_cast<DataIndexCourse**>(_v)); break;
        case 2: _t->setKind(*reinterpret_cast<enum Kind*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Course::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Course::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6CourseE_t>.strings))
        return static_cast<void*>(this);
    return CourseBase::qt_metacast(_clname);
}

int Course::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = CourseBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void Course::associatedDataIndexCourseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Course::lessonCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Course::kindChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Course::lessonAboutToBeAdded(Lesson * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void Course::lessonAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Course::lessonsAboutToBeRemoved(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void Course::lessonsRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
