/********************************************************************************
** Form generated from reading UI file 'customlessoneditordialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CUSTOMLESSONEDITORDIALOG_H
#define UI_CUSTOMLESSONEDITORDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "editor/lessontexteditor.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_CustomLessonEditorDialog
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *m_titleLabel;
    KLineEdit *m_titleLineEdit;
    QSpacerItem *m_verticalSpacer;
    LessonTextEditor *m_lessonTextEditor;
    QDialogButtonBox *m_buttonBox;

    void setupUi(QDialog *CustomLessonEditorDialog)
    {
        if (CustomLessonEditorDialog->objectName().isEmpty())
            CustomLessonEditorDialog->setObjectName("CustomLessonEditorDialog");
        CustomLessonEditorDialog->resize(601, 400);
        verticalLayout = new QVBoxLayout(CustomLessonEditorDialog);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        m_titleLabel = new QLabel(CustomLessonEditorDialog);
        m_titleLabel->setObjectName("m_titleLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, m_titleLabel);

        m_titleLineEdit = new KLineEdit(CustomLessonEditorDialog);
        m_titleLineEdit->setObjectName("m_titleLineEdit");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, m_titleLineEdit);


        verticalLayout->addLayout(formLayout);

        m_verticalSpacer = new QSpacerItem(20, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(m_verticalSpacer);

        m_lessonTextEditor = new LessonTextEditor(CustomLessonEditorDialog);
        m_lessonTextEditor->setObjectName("m_lessonTextEditor");

        verticalLayout->addWidget(m_lessonTextEditor);

        m_buttonBox = new QDialogButtonBox(CustomLessonEditorDialog);
        m_buttonBox->setObjectName("m_buttonBox");
        m_buttonBox->setOrientation(Qt::Horizontal);
        m_buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(m_buttonBox);


        retranslateUi(CustomLessonEditorDialog);
        QObject::connect(m_buttonBox, &QDialogButtonBox::accepted, CustomLessonEditorDialog, qOverload<>(&QDialog::accept));
        QObject::connect(m_buttonBox, &QDialogButtonBox::rejected, CustomLessonEditorDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(CustomLessonEditorDialog);
    } // setupUi

    void retranslateUi(QDialog *CustomLessonEditorDialog)
    {
        CustomLessonEditorDialog->setWindowTitle(tr2i18n("Dialog", nullptr));
        m_titleLabel->setText(tr2i18n("Title:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CustomLessonEditorDialog: public Ui_CustomLessonEditorDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CUSTOMLESSONEDITORDIALOG_H

