/****************************************************************************
** Meta object code from reading C++ file 'lessonpainter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktouch-26.08.0/src/declarativeitems/lessonpainter.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'lessonpainter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13LessonPainterE_t {};
} // unnamed namespace

template <> constexpr inline auto LessonPainter::qt_create_metaobjectdata<qt_meta_tag_ZN13LessonPainterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LessonPainter",
        "lessonChanged",
        "",
        "maximumWidthChanged",
        "maximumHeightChanged",
        "trainingLineCoreChanged",
        "cursorRectangleChanged",
        "done",
        "reset",
        "updateLayout",
        "resetTrainingStatus",
        "updateTrainingStatus",
        "advanceToNextTrainingLine",
        "lesson",
        "Lesson*",
        "maximumWidth",
        "maximumHeight",
        "trainingLineCore",
        "TrainingLineCore*",
        "cursorRectangle",
        "QRectF"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'lessonChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maximumWidthChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maximumHeightChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trainingLineCoreChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cursorRectangleChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'done'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reset'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateLayout'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'resetTrainingStatus'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateTrainingStatus'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'advanceToNextTrainingLine'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'lesson'
        QtMocHelpers::PropertyData<Lesson*>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'maximumWidth'
        QtMocHelpers::PropertyData<qreal>(15, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'maximumHeight'
        QtMocHelpers::PropertyData<qreal>(16, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'trainingLineCore'
        QtMocHelpers::PropertyData<TrainingLineCore*>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'cursorRectangle'
        QtMocHelpers::PropertyData<QRectF>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LessonPainter, qt_meta_tag_ZN13LessonPainterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LessonPainter::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickPaintedItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13LessonPainterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13LessonPainterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13LessonPainterE_t>.metaTypes,
    nullptr
} };

void LessonPainter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LessonPainter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->lessonChanged(); break;
        case 1: _t->maximumWidthChanged(); break;
        case 2: _t->maximumHeightChanged(); break;
        case 3: _t->trainingLineCoreChanged(); break;
        case 4: _t->cursorRectangleChanged(); break;
        case 5: _t->done(); break;
        case 6: _t->reset(); break;
        case 7: _t->updateLayout(); break;
        case 8: _t->resetTrainingStatus(); break;
        case 9: _t->updateTrainingStatus(); break;
        case 10: _t->advanceToNextTrainingLine(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LessonPainter::*)()>(_a, &LessonPainter::lessonChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LessonPainter::*)()>(_a, &LessonPainter::maximumWidthChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (LessonPainter::*)()>(_a, &LessonPainter::maximumHeightChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (LessonPainter::*)()>(_a, &LessonPainter::trainingLineCoreChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (LessonPainter::*)()>(_a, &LessonPainter::cursorRectangleChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (LessonPainter::*)()>(_a, &LessonPainter::done, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Lesson**>(_v) = _t->lesson(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->maximumWidth(); break;
        case 2: *reinterpret_cast<qreal*>(_v) = _t->maximumHeight(); break;
        case 3: *reinterpret_cast<TrainingLineCore**>(_v) = _t->trainingLineCore(); break;
        case 4: *reinterpret_cast<QRectF*>(_v) = _t->cursorRectangle(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLesson(*reinterpret_cast<Lesson**>(_v)); break;
        case 1: _t->setMaximumWidth(*reinterpret_cast<qreal*>(_v)); break;
        case 2: _t->setMaximumHeight(*reinterpret_cast<qreal*>(_v)); break;
        case 3: _t->setTrainingLineCore(*reinterpret_cast<TrainingLineCore**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *LessonPainter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LessonPainter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13LessonPainterE_t>.strings))
        return static_cast<void*>(this);
    return QQuickPaintedItem::qt_metacast(_clname);
}

int LessonPainter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickPaintedItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void LessonPainter::lessonChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void LessonPainter::maximumWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void LessonPainter::maximumHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void LessonPainter::trainingLineCoreChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void LessonPainter::cursorRectangleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void LessonPainter::done()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
