/****************************************************************************
** Meta object code from reading C++ file 'learningprogressmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktouch-26.08.0/src/models/learningprogressmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'learningprogressmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21LearningProgressModelE_t {};
} // unnamed namespace

template <> constexpr inline auto LearningProgressModel::qt_create_metaobjectdata<qt_meta_tag_ZN21LearningProgressModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LearningProgressModel",
        "profileChanged",
        "",
        "courseFilterChanged",
        "lessonFilterChanged",
        "maxCharactersTypedPerMinuteChanged",
        "minAccuracyChanged",
        "update",
        "profileDestroyed",
        "date",
        "row",
        "charactersPerMinute",
        "charactersTyped",
        "errorCount",
        "elapsedTime",
        "accuracy",
        "lessonId",
        "profile",
        "Profile*",
        "courseFilter",
        "Course*",
        "lessonFilter",
        "Lesson*",
        "maxCharactersTypedPerMinute",
        "minAccuracy"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'profileChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'courseFilterChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lessonFilterChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxCharactersTypedPerMinuteChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minAccuracyChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'update'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'profileDestroyed'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'date'
        QtMocHelpers::MethodData<QDateTime(int) const>(9, 2, QMC::AccessPublic, QMetaType::QDateTime, {{
            { QMetaType::Int, 10 },
        }}),
        // Method 'charactersPerMinute'
        QtMocHelpers::MethodData<int(int) const>(11, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 10 },
        }}),
        // Method 'charactersTyped'
        QtMocHelpers::MethodData<int(int) const>(12, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 10 },
        }}),
        // Method 'errorCount'
        QtMocHelpers::MethodData<int(int) const>(13, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 10 },
        }}),
        // Method 'elapsedTime'
        QtMocHelpers::MethodData<int(int) const>(14, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 10 },
        }}),
        // Method 'accuracy'
        QtMocHelpers::MethodData<qreal(int) const>(15, 2, QMC::AccessPublic, QMetaType::QReal, {{
            { QMetaType::Int, 10 },
        }}),
        // Method 'lessonId'
        QtMocHelpers::MethodData<QString(int) const>(16, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'profile'
        QtMocHelpers::PropertyData<Profile*>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'courseFilter'
        QtMocHelpers::PropertyData<Course*>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'lessonFilter'
        QtMocHelpers::PropertyData<Lesson*>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'maxCharactersTypedPerMinute'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags, 3),
        // property 'minAccuracy'
        QtMocHelpers::PropertyData<qreal>(24, QMetaType::QReal, QMC::DefaultPropertyFlags, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LearningProgressModel, qt_meta_tag_ZN21LearningProgressModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LearningProgressModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSqlQueryModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21LearningProgressModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21LearningProgressModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21LearningProgressModelE_t>.metaTypes,
    nullptr
} };

void LearningProgressModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LearningProgressModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->profileChanged(); break;
        case 1: _t->courseFilterChanged(); break;
        case 2: _t->lessonFilterChanged(); break;
        case 3: _t->maxCharactersTypedPerMinuteChanged(); break;
        case 4: _t->minAccuracyChanged(); break;
        case 5: _t->update(); break;
        case 6: _t->profileDestroyed(); break;
        case 7: { QDateTime _r = _t->date((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDateTime*>(_a[0]) = std::move(_r); }  break;
        case 8: { int _r = _t->charactersPerMinute((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 9: { int _r = _t->charactersTyped((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 10: { int _r = _t->errorCount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 11: { int _r = _t->elapsedTime((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 12: { qreal _r = _t->accuracy((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->lessonId((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LearningProgressModel::*)()>(_a, &LearningProgressModel::profileChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LearningProgressModel::*)()>(_a, &LearningProgressModel::courseFilterChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (LearningProgressModel::*)()>(_a, &LearningProgressModel::lessonFilterChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (LearningProgressModel::*)()>(_a, &LearningProgressModel::maxCharactersTypedPerMinuteChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (LearningProgressModel::*)()>(_a, &LearningProgressModel::minAccuracyChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Profile**>(_v) = _t->profile(); break;
        case 1: *reinterpret_cast<Course**>(_v) = _t->courseFilter(); break;
        case 2: *reinterpret_cast<Lesson**>(_v) = _t->lessonFilter(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->maxCharactersTypedPerMinute(); break;
        case 4: *reinterpret_cast<qreal*>(_v) = _t->minAccuracy(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setProfile(*reinterpret_cast<Profile**>(_v)); break;
        case 1: _t->setCourseFilter(*reinterpret_cast<Course**>(_v)); break;
        case 2: _t->setLessonFilter(*reinterpret_cast<Lesson**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *LearningProgressModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LearningProgressModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21LearningProgressModelE_t>.strings))
        return static_cast<void*>(this);
    return QSqlQueryModel::qt_metacast(_clname);
}

int LearningProgressModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSqlQueryModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void LearningProgressModel::profileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void LearningProgressModel::courseFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void LearningProgressModel::lessonFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void LearningProgressModel::maxCharactersTypedPerMinuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void LearningProgressModel::minAccuracyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
